CREATE TABLE SynchDeleteLog 
( 
	SynchDeleteLogId 			INTEGER PRIMARY KEY AUTOINCREMENT NOT NULL, 
	SynchTableId 				INTEGER NOT NULL, 
	KeyValues 					TEXT NOT NULL, 
	FieldValues 				TEXT 
);
go

CREATE TABLE SynchTable 
( 
	SynchTableId 					INTEGER PRIMARY KEY AUTOINCREMENT NOT NULL, 
	Name 							TEXT NOT NULL UNIQUE, 
	LastSynchDate 					DATETIME NOT NULL DEFAULT '1970-01-01 00:00:00.000', 
	IsUploadEnable 					INTEGER NOT NULL DEFAULT 1, 
	IsDownloadEnable 				INTEGER NOT NULL DEFAULT 1,
	TableId							INTEGER NOT NULL,
	LastSynchDateWithoutMultimedia	DATETIME NOT NULL DEFAULT '1970-01-01 00:00:00.000', 
	ContainMultimedia				INTEGER NOT NULL DEFAULT 0,
    MultimediaColumn				TEXT NULL,
	MultimediaExtensionColumn		TEXT NULL,
    ClearAfterUpload				INTEGER NULL
);
go

/*
	Informacja o replikacji.  
*/
CREATE TABLE SynchInfo
(
	SynchInfoId   INTEGER PRIMARY KEY AUTOINCREMENT,
	LastSynchDateBegin DATETIME NOT NULL DEFAULT '1970-01-01 00:00:00.000',
	LastSynchDateEnd DATETIME NOT NULL DEFAULT '1970-01-01 00:00:00.000',
	LastUploadBytes INTEGER,
	LastDownloadBytes INTEGER,
	SynchResult INTEGER NOT NULL, --1 sukces/0 błąd
	IsAuto INTEGER NOT NULL DEFAULT 0
);
go


-- Dane Pracownika:
CREATE TABLE dbo_User (
	UserId 			INTEGER NOT NULL,
	Name  			TEXT NULL,
	Login 			TEXT NOT NULL,
	Password			TEXT NOT NULL,
	IsAdmin 			INTEGER     NOT NULL,
	SystemId 			TEXT NOT NULL,
	GlobalAutoincrement	INTEGER NOT NULL,
	ReportWarehouseId	INTEGER NULL,
	SynchState  INTEGER NOT NULL DEFAULT 0,
	PRIMARY KEY (  UserId  )
 );
go

-- Dane firmy:
CREATE TABLE dbo_Company (
	CompanyId			INTEGER NOT NULL,
	Name				TEXT NOT NULL,
	FullName			TEXT NOT NULL,
	Nip				TEXT NULL,
	Regon				TEXT NULL,
	PostalCode		TEXT NULL,
	City				TEXT NULL,
	Street			TEXT NULL,
	LocumNumber		TEXT NULL,
	BankName			TEXT NULL,
	AccountNumber		TEXT NULL,
	DefaultTillId		INTEGER NOT NULL,
	PrintHeader		TEXT NULL,
	PrintFooter		TEXT NULL,
	SynchState  INTEGER NOT NULL DEFAULT 0,
	PRIMARY KEY ( CompanyId )
);
go

-- Pule numeracyjne:
CREATE TABLE dbo_UserPool (
	UserId			INTEGER NOT NULL,
	Type				INTEGER NOT NULL,
	FromDate			DATETIME NOT NULL,
	NextValue			INTEGER NOT NULL,
	SynchState  INTEGER NOT NULL DEFAULT 0,
	PRIMARY KEY (UserId, Type, FromDate)
);
go

-- pule numerowania dokumentów
CREATE TABLE dbo_DocNumeration (	
	UserId				INTEGER NOT NULL,
	DocumentCategory		INTEGER NOT NULL,
	DocumentType			INTEGER NOT NULL,
	ResourceId			INTEGER NOT NULL,
	Period				TEXT NOT NULL,
	NextValue				INTEGER NOT NULL,
	SynchState  INTEGER NOT NULL DEFAULT 0,
	PRIMARY KEY (UserId,DocumentCategory,DocumentType,ResourceId,Period)
);
go


-- ----------------------------------------------------------------------
-- ---------------------------- UPRAWNIENIA -----------------------------
-- ----------------------------------------------------------------------
-- definicje uprawnień
CREATE TABLE dbo_AccessDefinition ( 
	AppRightId			INTEGER NOT NULL,
	RightLevel			INTEGER NOT NULL,
	Range					INTEGER NOT NULL,
	Allow					INTEGER NOT NULL,
	SynchState  INTEGER NOT NULL DEFAULT 0,
	PRIMARY KEY (AppRightId,RightLevel,Range)
);
go

-- przypisania kas/magazynów
CREATE TABLE dbo_ResourceAssignment (	
	AppCardId				INTEGER NOT NULL,
	SourceId				INTEGER NOT NULL,
	ReadOnly				INTEGER NOT NULL,
	SynchState  INTEGER NOT NULL DEFAULT 0,
	PRIMARY KEY (AppCardId,SourceId)
);
go

-- ----------------------------------------------------------------------
-- @@@@@@@@@@@@@@@@@@@@@@@@@@@@@@ PRODUKTY @@@@@@@@@@@@@@@@@@@@@@@@@@@@@@
-- ----------------------------------------------------------------------
/* 
	+---------+    /+-----------------+\     +---------+
	| PRODUKT |-----| PRODUKT_MAGAZYN |------| MAGAZYN |
	+---------+    \+-----------------+/     +---------+
	                | PRODUKT_ID      |
	                | MAGAZYN_ID      |
	                | STAN            |
	                | REZERWACJA      |
	                +-----------------+
 */

-- Główna Tabela Produktów:
CREATE TABLE dbo_Product (
	ProductId				INTEGER NOT NULL,	
	CategoryId			INTEGER NULL,
	TaxSale				TEXT NULL,
	TaxSaleValue			FLOAT,
	TaxPurchase			TEXT NULL,
	TaxPurchaseValue		FLOAT,
	ProductType			INTEGER NULL,
	Name					TEXT NOT NULL,
	Name2					TEXT NULL,
	OriginalName			TEXT NULL,
	CatalogIndex			TEXT NOT NULL,
	TradeIndex			TEXT NOT NULL,
	SWWKU					TEXT NULL,
	PKWIU					TEXT NULL,
	Localisation			TEXT NULL,
	StockChange			INTEGER NULL,
	Discountable 			INTEGER NULL,
	PromoDateBeg			DATETIME NULL,
	PromoDateEnd			DATETIME NULL,
	PromoNetPrice			FLOAT,
	PromoGrossPrice		FLOAT,
	PromoPriceDiscountable INTEGER NULL,
	Warning				TEXT NULL,
	ShowWarning			INTEGER NULL,
	Description			TEXT NULL,
	Remarks				TEXT NULL,
	WarehouseLock			INTEGER NOT NULL,
	BarCode				TEXT NULL,
	CategoryTreeId		INTEGER NULL,
	PromoDiscountPercent 	FLOAT NULL,
	SynchState  INTEGER NOT NULL DEFAULT 0,
	PRIMARY KEY ( ProductId )
);
go

CREATE TABLE dbo_ProductWarehouse (
	ProductUniqueId		INTEGER NOT NULL,
	ProductId				INTEGER NOT NULL,
	WarehouseId			INTEGER NOT NULL,
	Stock					FLOAT,
	Reserved				FLOAT,
	DefaultPriceId		INTEGER NULL,
	UnitId				INTEGER NOT NULL,
	PurchaseUnitId		INTEGER NOT NULL,
	SaleUnitId			INTEGER NOT NULL,
	PurchaseNetPrice		FLOAT,
	PurchaseGrossPrice	FLOAT,
	LocalStock			FLOAT,
	LocalReserved			FLOAT,
	StockMinimum			FLOAT,
	StockMaximum			FLOAT,
	MinMarkUp				FLOAT, -- minimalny narzut (jako stosunek zysku (netto) do ceny zakupu (netto) wyrażony w procentach)
	SynchState  INTEGER NOT NULL DEFAULT 0,
	PRIMARY KEY ( ProductUniqueId )
);
go

CREATE INDEX idx_dbo_ProductWarehouse ON dbo_ProductWarehouse (ProductId);
go

-- Stosowane Jednostki Miary
CREATE TABLE dbo_Unit (
	UnitId				INTEGER NOT NULL,
	Name					TEXT NOT NULL,
	Divisible				INTEGER NOT NULL,
	SynchState  INTEGER NOT NULL DEFAULT 0,
	PRIMARY KEY ( UnitId )
);
go

-- Kody kreskowe
CREATE TABLE dbo_Barcode (
	BarcodeId				INTEGER NOT NULL,
	WarId					TEXT NOT NULL,
	BarCode                 TEXT NOT NULL,
	ProductId               INTEGER NOT NULL,
	UnitId                  INTEGER NULL,
	DefQuantity             FLOAT NULL,
	Description             TEXT NULL,
	SynchState  INTEGER NOT NULL DEFAULT 0,
	PRIMARY KEY ( BarcodeId )
);
go

-- Przeliczniki Jednostek Dla Produktów
CREATE TABLE dbo_ProductUnit (
	ProductUniqueId		INTEGER NOT NULL,
	UnitId				INTEGER NOT NULL,
	ConversionRate		FLOAT,
	Divisible				INTEGER NULL,
	SynchState  INTEGER NOT NULL DEFAULT 0,
	PRIMARY KEY ( ProductUniqueId, UnitId )
);
go

-- słownik kategorii produktowych
CREATE TABLE dbo_ProductCategory (
	CategoryId			INTEGER NOT NULL,
	Name					TEXT NOT NULL,    
	SynchState  INTEGER NOT NULL DEFAULT 0,
	PRIMARY KEY (CategoryId)
);
go

-- słownik kategorii produktowych wielopoziomowych
CREATE TABLE dbo_ProductCategoryTree (
	CategoryId			INTEGER NOT NULL,
	Name					TEXT NOT NULL,
    ParentCategoryId    INTEGER,
	SynchState  INTEGER NOT NULL DEFAULT 0,
	PRIMARY KEY (CategoryId)
);
go

-- Cennik indywidualny (kontrahenta lub grupy cenowej kontrahenta). Zawiera tylko ceny sprzedaży, ceny zakupu będą podawane w ProductWarehouse
CREATE TABLE dbo_IndividualPrice (
	SourceType			INTEGER NOT NULL,
	SourceId				INTEGER NOT NULL,
	ProductUniqueId		INTEGER NOT NULL,
	IndividualIndex		TEXT NOT NULL,
	IndividualName		TEXT NOT NULL,
	PriceMode				INTEGER NOT NULL,
	PriceId				INTEGER NULL,
	Discount				FLOAT,
	NetPrice				FLOAT,
	GrossPrice			FLOAT,
	SynchState  INTEGER NOT NULL DEFAULT 0,
	PRIMARY KEY (SourceType,SourceId,ProductUniqueId)
);
go

-- cennik ogólny
CREATE TABLE dbo_ProductPrice (
	ProductUniqueId		INTEGER NOT NULL,
	PriceId				INTEGER NOT NULL,
	NetPrice				FLOAT,
	GrossPrice			FLOAT,
	SynchState  INTEGER NOT NULL DEFAULT 0,
	PRIMARY KEY (ProductUniqueId,PriceId)
);
go

-- ---------------------------------------------------------------------
-- ++++++++++++++++++++++++++++++ KLIENCI ++++++++++++++++++++++++++++++
-- ---------------------------------------------------------------------
CREATE TABLE dbo_Customer (
	CustomerId			INTEGER NOT NULL,
	PayerId				INTEGER NOT NULL,
	CustomerStatus		INTEGER NULL,
	GroupId				INTEGER NULL,
	ClassificationId		INTEGER NULL,
	Name					TEXT NULL,
	FullName				TEXT NULL,
	DistinguishFeature	TEXT NULL,
	PESEL					TEXT NULL,
	NIP					TEXT NULL,
	NIPL					TEXT NULL,
	REGON					TEXT NULL,
	Recipient				INTEGER NULL,
	Supplier				INTEGER NULL,
	TaxPayer				INTEGER NULL,
	PersDataAgreement		INTEGER	NULL,
	RegionId				INTEGER NOT NULL,
	PostalCode			TEXT NULL,
	City					TEXT NULL,
	Street				TEXT NULL,
	LocumNumber			TEXT NULL,
	Homepage				TEXT NULL,
	Email					TEXT NULL,
	TradeCredit			FLOAT,
	DaysDelay				INTEGER NOT NULL,
	
	-- *!* mobilny ma mieć parametr czy dopuszczać możliwość wystawienia zamówienia klientowi zablokowanemu	*!*
	SaleLock				INTEGER NULL,
										  -- 2-dla przeterminowanych należności (powyżej <X> dni po terminie, limit nie brany pod uwagę), 
										  -- 3-dla przeterm. należności powyżej limitu (należności przeterminowane powyżej <X> dni przekraczają kwotę <Y>), 
										  -- 4-dla wszystkich należności powyżej limitu (kwota powyżej <Y>, dni nie brane pod uwagę), 
										  -- 5- (albo,albo) dla wszystkich należności powyżej limitu lub przeterm.
	
	DefDiscount			FLOAT,
	DefPaymentForm		INTEGER NULL,
	TermReceivables		INTEGER NOT NULL,
	TermLiabilities		INTEGER NOT NULL,
	ShowWarning			INTEGER NULL,
	Warning				TEXT NULL,
	Remarks				TEXT NULL,
	DeleteProposal		INTEGER NOT NULL,
	UserId				INTEGER NULL,
	WarehouseLock		INTEGER NOT NULL,
	RouteKindId			INTEGER NOT NULL,
	Latitude			FLOAT,
	Longitude			FLOAT,
	SystemId			TEXT NULL,
	InPromotion			INTEGER,
	SynchState  		INTEGER NOT NULL DEFAULT 0,
	PRIMARY KEY (CustomerId)
);
go
CREATE INDEX idx_dbo_Customer ON dbo_Customer (CustomerId);
go

-- grupa cenowa dla kategorii asortymentowych
CREATE TABLE dbo_CustomerGroupPrice (	
	GroupId				INTEGER NOT NULL,
	CategoryId			INTEGER NOT NULL,
	PriceId				INTEGER NOT NULL,
	Discount				FLOAT,
	SynchState  INTEGER NOT NULL DEFAULT 0,
	PRIMARY KEY (GroupId,CategoryId)
);
go

-- grupa cenowa kontrahenta
CREATE TABLE dbo_CustomerGroup (	
	GroupId				INTEGER NOT NULL,
	PriceId				INTEGER NULL,
	Discount				FLOAT,
	Name					TEXT NOT NULL,	
	SynchState  INTEGER NOT NULL DEFAULT 0,
	PRIMARY KEY (GroupId)
);
go

-- klasyfikacja kontrahenta
CREATE TABLE dbo_CustomerClassification ( 
	ClassificationId		INTEGER NOT NULL,
	Name					TEXT NOT NULL,
	Description			TEXT NULL,
	SynchState  INTEGER NOT NULL DEFAULT 0,
	PRIMARY KEY (ClassificationId)
);
go

-- klient: osoby kontaktowe
CREATE TABLE dbo_CustomerContact (	
	ContactId				INTEGER NOT NULL,
	CustomerId			INTEGER NOT NULL,
	IsDefault				INTEGER NOT NULL,
	Position				TEXT NULL,
	FirstName				TEXT NULL,
	LastName				TEXT NULL,
	PhoneNo				TEXT NULL,
	CellPhoneNo			TEXT NULL,
	Fax					TEXT NULL,	
	Email					TEXT NULL,
	Remarks				TEXT NULL,
	SynchState  INTEGER NOT NULL DEFAULT 0,
	PRIMARY KEY (ContactId)
);
go

-- klient: konta bankowe
CREATE TABLE dbo_CustomerBankAccount (	
	AccountId				INTEGER NOT NULL,
	CustomerId			INTEGER NOT NULL,
	BankName				TEXT NOT NULL,
	BankNumber			TEXT NULL,
	AccountNumber			TEXT NOT NULL,
	IsDefault				INTEGER NOT NULL,
	Description			TEXT NULL,
	SynchState  INTEGER NOT NULL DEFAULT 0,
	PRIMARY KEY (AccountId)
);
go


-- ---------------------------------------------------------------------
-- ############################# DOKUMENTY #############################
-- ---------------------------------------------------------------------
CREATE TABLE dbo_Document (
	DocumentId			INTEGER NOT NULL,
	Type					INTEGER NOT NULL,
	SubType				INTEGER NULL,
	Status				INTEGER NOT NULL,
	WarehouseId			INTEGER NULL,
	CustomerId			INTEGER NOT NULL,
	PayerId				INTEGER NOT NULL,
	UserId				INTEGER NOT NULL,
	Number				TEXT NOT NULL,
	IssueDate				DATETIME NOT NULL,
	SellDate				DATETIME NULL,
	IssuePlace			TEXT NULL,
	CreateDate			DATETIME NOT NULL,
	CompletionDate		DATETIME NULL,
	PriceForm				INTEGER NOT NULL,
	AutoReservation		INTEGER NULL,
	Priority				INTEGER NULL,
	PaymentFormId			INTEGER NULL,
	PaymentTerm			INTEGER NULL,
	PaymentDate			DATETIME NULL,
	SourceDocId			INTEGER NULL,
	SourceDocNumber		TEXT NULL,
	SourceDocDate			DATETIME NULL,
	Discount				FLOAT,
	DiscountMode			INTEGER NOT NULL,
	DiscountWorthNet		FLOAT,
	DiscountWorthGross	FLOAT,
	WorthNet				FLOAT,
	WorthGross			FLOAT,
	WorthPayments			FLOAT,
	Paid					INTEGER NOT NULL,
	Remarks				TEXT NULL,
	ContactId				INTEGER NULL,
	RemoteDelFlag			INTEGER NOT NULL,
	PrintCount			INTEGER NOT NULL,
	DocStatusExtId		INTEGER NULL,
	DocStatusExtRemarks	TEXT NULL,
	NumberValue			INTEGER NULL,
	TargetWarehouseId	INTEGER NULL,
	PrevDocumentId		INTEGER NULL,  -- id dokumentu z którego kopiujemy
	Version				INTEGER NULL,
	--------------------
	CurrencyWorthNet 		FLOAT NULL,
	CurrencyWorthGross 		FLOAT NULL,
	CurrencyWorthPayments 	FLOAT NULL,
	CurrencySymbol 			TEXT NULL ,
	CurrencyConverter 		FLOAT NULL,
	SynchState  INTEGER NOT NULL DEFAULT 0,
	PRIMARY KEY (DocumentId)
);
go

CREATE INDEX idx_dbo_IdxDocumentIssueDate ON dbo_Document (IssueDate DESC);
go

CREATE TABLE dbo_DocumentDetail (
	DocumentDetailId	INTEGER NOT NULL,
	TradeDocumentId		INTEGER NULL,
	WarehouseDocumentId	INTEGER NULL,
	DocumentPos			INTEGER NOT NULL,
	ProductUniqueId		INTEGER NOT NULL,
	WarehouseId			INTEGER NOT NULL,
	ProductType			INTEGER NOT NULL,
	StockChange			INTEGER NOT NULL,
	TaxCode				TEXT NOT NULL,
	TaxValue			FLOAT,
	NetPrice			FLOAT,
	GrossPrice			FLOAT,
	Discount			FLOAT,
	DiscountTotal		FLOAT,
	NetPriceDiscount	FLOAT,
	GrossPriceDiscount	FLOAT,
	Quantity			FLOAT,
	Reserved			FLOAT,
	UnitId				INTEGER NOT NULL,
	ConversionRate		FLOAT,
	WorthNet			FLOAT,
	WorthGross			FLOAT,
	Remarks				TEXT NULL,
	PriceType			INTEGER NULL,
	OrderDocumentId		INTEGER NULL,
	BaseQuantity		FLOAT NULL,
	SynchState  INTEGER NOT NULL DEFAULT 0,
	PRIMARY KEY (DocumentDetailId)
);
go

CREATE INDEX idx_dbo_IdxDocumentDetailProductUniqueId ON dbo_DocumentDetail (ProductUniqueId);
go

-- tabela zawiera nagłówki zamówień pochodzących z systemów producenckich. Zamówienia takie mają trafić na urządzenie odpowiedniego PH dla dokonania ewentualnej korekty i akceptacji.
CREATE TABLE dbo_DocOrderProducer ( 
	DocumentId			INTEGER NOT NULL,
	NumOrderProd			TEXT NULL,
	CustomerId			INTEGER NOT NULL,
	OrderDate				DATETIME NOT NULL,
	PaymentFormId			INTEGER NOT NULL,
	PaymentTerm			INTEGER NOT NULL,
	Status				INTEGER NOT NULL,
	Remarks				TEXT NULL,
	WarehouseId			INTEGER NULL,
	AlertPointer			INTEGER NOT NULL,
	SynchState  INTEGER NOT NULL DEFAULT 0,
	PRIMARY KEY (DocumentId)
);
go

-- tabela zawiera pozycje zamówień producenckich.
CREATE TABLE dbo_DocOrderProducerDetail ( 
	DocumentDetailId		INTEGER NOT NULL,
	ProductUniqueId		INTEGER NOT NULL,
	Quantity				FLOAT,
	UnitId				INTEGER NOT NULL,
	SynchState  INTEGER NOT NULL DEFAULT 0,
	PRIMARY KEY (DocumentDetailId,ProductUniqueId)	
);
go

-- tabela zawiera powiązanie pomiędzy zamówieniami producenckimi i powstałymi na ich podstawie zamówieniami 
CREATE TABLE dbo_DocOrderProducer_Order (  
	DocOrderProducerId		INTEGER NOT NULL,
	OrderId					INTEGER NOT NULL,
	SynchState  INTEGER NOT NULL DEFAULT 0,
	PRIMARY KEY (DocOrderProducerId,OrderId)	
);
go

-- dokument wg stawek VAT
CREATE TABLE dbo_DocumentTax (	
	DocumentId			INTEGER NOT NULL,
	TaxCode				TEXT NOT NULL,
	WorthNet				FLOAT,
	WorthTax				FLOAT,
	WorthGross			FLOAT,
	SynchState  INTEGER NOT NULL DEFAULT 0,
	PRIMARY KEY (DocumentId,TaxCode),
    FOREIGN KEY (DocumentId) REFERENCES FKDocumentTax (DocumentId)
);
go

--ALTER TABLE dba.DocumentTax ADD NOT NULL FOREIGN KEY FKDocumentTax (DocumentId) 	REFERENCES dba.Document (DocumentId)go

-- błędy w dokumentach
CREATE TABLE dbo_DocumentError (	
	DocumentId			INTEGER NOT NULL,
	Type					INTEGER NOT NULL,
	DocumentDetailId		INTEGER NOT NULL,
	ErrorTypeId			INTEGER NOT NULL,
	Name					TEXT NOT NULL,
	Description			TEXT NULL,
	SynchState  INTEGER NOT NULL DEFAULT 0,
	PRIMARY KEY (DocumentId,Type,DocumentDetailId,ErrorTypeId)
);
go

-- zewnętrzne statusy dokumentów
CREATE TABLE dbo_DocStatusExt (	
	DocStatusExtId 		INTEGER NOT NULL,
	Name 					TEXT NOT NULL,
	SynchState  INTEGER NOT NULL DEFAULT 0,
	PRIMARY KEY (DocStatusExtId)
);
go


-- ---------------------------------------------------------------------
-- $$$$$$$$$$$$$$$$$$$$$$$$$$$ ROZRACHUNKI $$$$$$$$$$$$$$$$$$$$$$$$$$$$$
-- ---------------------------------------------------------------------
-- rozrachunek do rozliczenia
CREATE TABLE dbo_Bill (	
	BillId				INTEGER NOT NULL,
	Type					INTEGER NOT NULL,
	PayerId				INTEGER NOT NULL,
	DocumentId			INTEGER NULL,
	Number				TEXT NOT NULL,
	IssueDate				DATETIME NULL,
	CreateDate			DATETIME NOT NULL,
	PaymentDate			DATETIME NOT NULL,
	WorthGross			FLOAT,
	WorthPayments			FLOAT,
	Paid					INTEGER NOT NULL,
	UserId				INTEGER NULL,
	CurrencyWorthGross 		FLOAT NULL,
	CurrencyWorthPayments 	FLOAT NULL,
	CurrencySymbol 			TEXT NULL ,
	CurrencyConverter 		FLOAT NULL,
	SynchState  INTEGER NOT NULL DEFAULT 0,
	PRIMARY KEY (BillId)
);
go

-- nagłówek dokumentu kasowego
CREATE TABLE dbo_FinancialDocument (	
	FinDocId			INTEGER NOT NULL,
	Type				INTEGER NOT NULL,
	Status				INTEGER NOT NULL,
	CustomerId			INTEGER NOT NULL,
	PayerId				INTEGER NOT NULL,
	UserId				INTEGER NOT NULL,
	TillId				INTEGER NOT NULL,
	Number				TEXT NOT NULL,
	IssueDate			DATETIME NOT NULL,
	CreateDate			DATETIME NOT NULL,
	Amount				FLOAT,	
	Remarks				TEXT NULL,
	RemoteDelFlag		INTEGER NOT NULL,
	PrintCount			INTEGER NOT NULL,
	NumberValue			INTEGER NULL,
	CurrencyAmount		FLOAT NULL,
	CurrencySymbol		TEXT NULL,
	CurrencyConverter	FLOAT NULL,
	SynchState  INTEGER NOT NULL DEFAULT 0,
	PRIMARY KEY (FinDocId)
);
go

-- pozycja dokumentu kasowego
CREATE TABLE dbo_FinancialDocDetail (	
	FinDocDetailId		INTEGER NOT NULL,
	FinDocId			INTEGER NOT NULL,
	BillId				INTEGER NULL,
	DocumentId			INTEGER NULL,
	Amount				FLOAT,
	Title				TEXT NULL,
	CurrencyAmount		FLOAT NULL,
	CurrencySymbol		TEXT NULL,
	CurrencyConverter	FLOAT NULL,
	SynchState  INTEGER NOT NULL DEFAULT 0,
	PRIMARY KEY (FinDocDetailId),
    FOREIGN KEY (FinDocId) REFERENCES dbo_FinancialDocument (FinDocId)
);
go

--ALTER TABLE dba.FinancialDocDetail ADD NOT NULL FOREIGN KEY FKFinDocDetail (FinDocId) REFERENCES dba.FinancialDocument (FinDocId)go
-- ---------------------------------------------------------------------
-- 		***** TRASÓWKI *****
-- ---------------------------------------------------------------------
CREATE TABLE dbo_Route (
	RouteId				INTEGER NOT NULL,
	UserId				INTEGER NOT NULL,
	RouteDate				DATETIME NOT NULL,
	Approved				INTEGER NOT NULL,
	SynchState  INTEGER NOT NULL DEFAULT 0,
	PRIMARY KEY (RouteId)
);
go

CREATE TABLE dbo_RouteDetail (
	RouteId				INTEGER NOT NULL,
	CustomerId			INTEGER NOT NULL,
	HourPlan				DATETIME NOT NULL,
	HourBeg				DATETIME NULL,
	HourEnd				DATETIME NULL,
	Status				INTEGER NOT NULL,
	Annexed				INTEGER NOT NULL,
	Remarks				TEXT NULL,
	Mileage				INTEGER NULL,
	RouteKindId			INTEGER NOT NULL,
	SynchState  INTEGER NOT NULL DEFAULT 0,
	ContactId			INTEGER NULL,
	PRIMARY KEY (RouteId,CustomerId)
);
go

-- ---------------------------------------------------------------------
-- 		SŁOWNIKI
-- ---------------------------------------------------------------------
-- forma płatności
CREATE TABLE dbo_PaymentForm ( 
	PaymentFormId			INTEGER NOT NULL,
	Name					TEXT NOT NULL,
	TermReceivables		INTEGER NOT NULL,
	TermLiabilities		INTEGER NOT NULL,
	SynchState  INTEGER NOT NULL DEFAULT 0,
	PRIMARY KEY (PaymentFormId)
);
go

-- województwo
CREATE TABLE dbo_Region ( 
	RegionId				INTEGER NOT NULL,
	Name					TEXT NOT NULL,
	SynchState  INTEGER NOT NULL DEFAULT 0,
	PRIMARY KEY (RegionId)
);
go

-- magazyn
CREATE TABLE dbo_Warehouse (	
	WarehouseId			INTEGER NOT NULL,
	Name					TEXT NOT NULL,
	Symbol				TEXT NOT NULL,
	SynchState  INTEGER NOT NULL DEFAULT 0,
	PRIMARY KEY (WarehouseId)
);
go

-- nazwa ceny
CREATE TABLE dbo_Price (	
	PriceId				INTEGER NOT NULL,
	Name					TEXT NOT NULL,
	SynchState  INTEGER NOT NULL DEFAULT 0,
	PRIMARY KEY (PriceId)
);
go

-- historia cen
CREATE TABLE dbo_PriceHistory (	
	PriceHistoryId		INTEGER NOT NULL,
	DocumentId			INTEGER NOT NULL,
	ProductId			INTEGER NOT NULL,
	Price				FLOAT NOT NULL,
	Date				DATETIME NOT NULL,	
	SynchState  		INTEGER NOT NULL DEFAULT 2,
	PRIMARY KEY (PriceHistoryId)
);
go

-- waluty
CREATE TABLE dbo_Currency (	
	CurrencyId		INTEGER NOT NULL,
	Symbol			TEXT NOT NULL,
	Rate			FLOAT NOT NULL,
	SynchState  	INTEGER NOT NULL DEFAULT 0,
	PRIMARY KEY (CurrencyId)
);
go

-- targety
CREATE TABLE dbo_TargetMeasure 
(	
	TargetMeasureId		INTEGER NOT NULL,
	Name				TEXT NOT NULL,
	SynchState  		INTEGER NOT NULL DEFAULT 0,
	PRIMARY KEY (TargetMeasureId)
);
go

-- kasa
CREATE TABLE dbo_Till	(	
	TillId				INTEGER NOT NULL,
	Name				TEXT NOT NULL,
	Symbol				TEXT NOT NULL,
	SynchState  INTEGER NOT NULL DEFAULT 0,
	PRIMARY KEY (TillId)
);
go

-- rodzaje kontaktów (wizyt)
CREATE TABLE dbo_RouteKind (		
	RouteKindId 			INTEGER NOT NULL,		
	RouteKindItr 			TEXT NOT NULL,
	RouteName				TEXT NOT NULL,
	RouteNameButton 		TEXT NOT NULL,
	SynchState  INTEGER NOT NULL DEFAULT 0,
	PRIMARY KEY (RouteKindId)
);
go

CREATE TABLE dbo_DocRemarks (
	DocRemarksId		INTEGER NOT NULL,
	LevelId				INTEGER NOT NULL Default 0, -- 0 - system, 1 - firma, 2 - pracownik 
	SourceId			INTEGER NOT NULL Default -1, -- zależnie od LevelId - identyfikator firmy, pracownika lub -1 systemu
	DocTypeId 			INTEGER NOT NULL Default 0, -- typ dokumentu w ramach kategorii:
													--0-Default,1-FV,2-PF,3-ZO,4-ZD,7-OF,11-WZ,12-SU,13-MW,14-MP,15-RW,16-PW,21-KP,22-KW, 
	Remarks			 	TEXT NOT NULL, -- treść uwag
	IsDefault		 	INTEGER NOT NULL Default 0, -- domyslnie 0 – wyświetlają się wszystkie uwagi do wyboru, a ta jest wybrana domyślnie 
													-- zasada jedna domyślna uwaga w danej kategorii dokumentów, dla danego dokumentu lub dla danego użytkownika
	PRIMARY KEY (DocRemarksId)
);
go
 
-- ---------------------------------------------------------------------
-- 		SYNCHRONIZACJA CZASU
-- ---------------------------------------------------------------------
CREATE TABLE dbo_PubTime (
	ServerTime			DATETIME NOT NULL,
	SynchState  INTEGER NOT NULL DEFAULT 0,
	PRIMARY KEY (ServerTime)
);
go

--CREATE PUBLICATION PubSynchTime (
--	TABLE PubTime
--)
--go

-- ---------------------------------------------------------------------
-- 		PARAMETRY
-- ---------------------------------------------------------------------
CREATE TABLE dbo_Parameter (
	ParameterId			INTEGER NOT NULL,
	ParameterValue		TEXT NOT NULL,
	SynchState  INTEGER NOT NULL DEFAULT 0,
	PRIMARY KEY (ParameterId)
);
go

-- ustawienia numerowania dokumentów
CREATE TABLE dbo_DocNumerationDef (	
	DocumentCategory		INTEGER NOT NULL,
	DocumentType			INTEGER NOT NULL,
	ResourceId			INTEGER NOT NULL,
	Periodicity			INTEGER NOT NULL,
	ResourceDependency	INTEGER NOT NULL,
	NumerationMode		INTEGER NOT NULL,
	NumberTemplate		TEXT NOT NULL,
	SynchState  INTEGER NOT NULL DEFAULT 0,
	PRIMARY KEY (DocumentCategory, DocumentType, ResourceId)
);
go
-- ---------------------------------------------------------------------
-- 		DZIEŃ PRACY
-- ---------------------------------------------------------------------
CREATE TABLE dbo_DayReport (
	DayReportId			INTEGER NOT NULL,
	UserId				INTEGER NOT NULL,
	ReportDate			DATETIME NOT NULL,
	MileageStart			INTEGER NOT NULL,
	MileageStop			INTEGER NULL,
	CarChanged			INTEGER NOT NULL,
	Closed				INTEGER NOT NULL,
	SynchState  INTEGER NOT NULL DEFAULT 0,
	PRIMARY KEY (DayReportId)
);
go
-- ---------------------------------------------------------------------
-- 		WIADOMOŚCI PH
-- ---------------------------------------------------------------------
CREATE TABLE dbo_Message (
	MessageId				INTEGER NOT NULL,
	MessageBody			TEXT NOT NULL,
	MessageDate			DATETIME NOT NULL,
	Status				INTEGER NOT NULL,
	SynchState  INTEGER NOT NULL DEFAULT 0,
	PRIMARY KEY (MessageId)
);
go
-- ----------------------------------------------------------------------
-- &&&&&&&&&&&&&&&&&&&&&&&&&&&& RAPORTY &&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&
-- ----------------------------------------------------------------------
-- nazwy raportów
CREATE TABLE dbo_Report (	
	ReportId				INTEGER NOT NULL,
	Name					TEXT NOT NULL,
	NameValue1			TEXT NULL,
	NameValue2			TEXT NULL,
	TypeValue1			INTEGER NULL,
	TypeValue2			INTEGER NULL,
	SynchState  INTEGER NOT NULL DEFAULT 0,
	PRIMARY KEY (ReportId)
);
go

-- żądanie raportu
CREATE TABLE dbo_ReportRequest (	
	UserId				INTEGER NOT NULL,
	ReportId				INTEGER NOT NULL,
	DateFrom				DATETIME NOT NULL,
	DateTo				DATETIME NOT NULL,
	Status				INTEGER NOT NULL,
	SynchState  INTEGER NOT NULL DEFAULT 0,
	PRIMARY KEY (UserId, ReportId)
);
go

-- wartości raportów
CREATE TABLE dbo_ReportValues (	
	ReportId				INTEGER NOT NULL,
	ResourceId			INTEGER NOT NULL,
	Name					TEXT NOT NULL,
	Value1				FLOAT,
	Value2				FLOAT,
	SynchState  INTEGER NOT NULL DEFAULT 0,
	PRIMARY KEY (ReportId, ResourceId)
);
go

-- ----------------------------------------------------------------------
--      TŁUMACZENIA - WIELOJĘZYKOWOŚĆ
-- ----------------------------------------------------------------------
-- obsługiwane słowniki
CREATE TABLE dbo_TranslateDictionary ( 
	DictionaryId			INTEGER NOT NULL,
	Name					TEXT NOT NULL,
	FileName				TEXT NULL,
	SynchState  INTEGER NOT NULL DEFAULT 0,
	PRIMARY KEY ( DictionaryId )
);
go

-- słownik wyrażeń
CREATE TABLE dbo_MobileTranslation ( 
	DictionaryId			INTEGER NOT NULL,
	WordId				INTEGER NOT NULL,
	Name					TEXT NOT NULL,
	RecordUpdated			INTEGER NOT NULL,
	SynchState  INTEGER NOT NULL DEFAULT 0,
	PRIMARY KEY (DictionaryId, WordId)
);
go

-- ----------------------------------------------------------------------
-- ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~ ATRYBUTY ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
-- ----------------------------------------------------------------------
-- definicja atrybutu w kartotece (ten sam atrybut może występować w więcej niż jednej kartotece)
CREATE TABLE dbo_Attribute (			
	AppCardId 				INTEGER NOT NULL, -- 43-produkt, 2-kontrahent, 90-pozycja dok. handlowego, 92-pozycja dok. magazynowego, 94-pozycja zamówienia
	AttributeId 			INTEGER NOT NULL,
	AttributeTypeId 		INTEGER NOT NULL, -- typ atrybutu (tabela AttributeType): 1-liczba całkowita, 2-liczba rzeczywista, 3-tekst, 4-data, 5-tak/nie, 6-wybór z listy (jeden z wielu)
	Name 					TEXT NOT NULL, 	-- nazwa atrybutu
	ValueMin 				TEXT NULL,
	ValueMax 				TEXT NULL,
	ValueDefault 			TEXT NULL,
	Required 				INTEGER NOT NULL,  -- wskaźnik obowiązkowości atrybutu
	Sequence 				INTEGER NULL, -- porządek atrybutu w sekwencji
	SynchState  INTEGER NOT NULL DEFAULT 0,
	PRIMARY KEY (AppCardId, AttributeId)
);
go

-- wartości dla atrybutu typu 6 (wybór z listy)
CREATE TABLE dbo_AttributeDetail (	
	AttributeDetailId 		INTEGER NOT NULL,
	AttributeId 			INTEGER NOT NULL,
	Name 					TEXT NOT NULL,
	Sequence 				INTEGER NOT NULL, -- kolejność na ew. liście wyboru
	SynchState  INTEGER NOT NULL DEFAULT 0,
	PRIMARY KEY (AttributeDetailId)
);
go
CREATE INDEX idx_dbo_IdxAttributeDetailAttributeId ON dbo_AttributeDetail (AttributeId);
go

-- wartości atrybutów w kartotekach
CREATE TABLE dbo_AttributeValue (		
	AppCardId 					INTEGER NOT NULL, -- 43-produkt, 2-kontrahent, 90-pozycja dok. handlowego, 92-pozycja dok. magazynowego, 94-pozycja zamówienia, 60001-zdjecia produktu
	SourceId 					INTEGER NOT NULL, -- id produktu (ProductUniqueId) / kontrahenta (CustomerId) / pozycji dokumentu (DocumentDetailId)
	AttributeId 				INTEGER NOT NULL, -- id atrybutu (AttributeId)
	Value 						TEXT NOT NULL,
	AttributeValueBinaryId 		INTEGER NULL,		-- wypełnione dla zdjęć
	AttributeValueBinaryCollectionId INTEGER NULL,	-- wypełnione dla galerii zdjęć
	CatalogIndex 				TEXT NULL,	-- wypełnione gdy AppCardId = 60001
	SynchState  				INTEGER NOT NULL DEFAULT 0,
	PRIMARY KEY (AppCardId,SourceId,AttributeId)
);
go


-- ----------------------------------------------------------------------
-- ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~ Targety ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
-- ----------------------------------------------------------------------
CREATE TABLE dbo_TargetAlgorithm
(
	TargetAlgorithmId	 INTEGER NOT NULL,
	TargetMeasureId		 INTEGER NOT NULL,
	Name				 TEXT NOT NULL,
	SynchState  		 INTEGER NOT NULL DEFAULT 0,
    PRIMARY KEY (TargetAlgorithmId)
);
go

CREATE TABLE dbo_TargetProfile
(
	TargetProfileId		 INTEGER NOT NULL,
	Name				 TEXT NOT NULL,
	Description			 TEXT NULL,
	SynchState  		 INTEGER NOT NULL DEFAULT 0,
    PRIMARY KEY (TargetProfileId)
);
go

CREATE TABLE dbo_TargetProfileItemType
(
	TargetProfileItemTypeId			 INTEGER NOT NULL,
	Name							 TEXT NOT NULL,
	TableName						 TEXT NOT NULL,
	TableKeyName					 TEXT NOT NULL,
	SynchState  					 INTEGER NOT NULL DEFAULT 0,
    PRIMARY KEY (TargetProfileItemTypeId)
);
go

CREATE TABLE dbo_TargetProfileItem
(
	TargetProfileItemId			 INTEGER NOT NULL,
	TargetProfileId				 INTEGER NOT NULL,
	TargetProfileItemTypeId		 INTEGER NOT NULL,
	ItemId						 INTEGER NOT NULL,
	SynchState  				 INTEGER NOT NULL DEFAULT 0,
    PRIMARY KEY (TargetProfileItemId)
);
go

CREATE TABLE dbo_TargetTemplate
(
	TargetTemplateId			 INTEGER NOT NULL,
	TargetProfileId				 INTEGER NOT NULL,
	TargetAlgorithmId			 INTEGER NOT NULL,
	Name						 TEXT NOT NULL,
	Description					 TEXT NULL,
	SynchState  				 INTEGER NOT NULL DEFAULT 0,
    PRIMARY KEY (TargetTemplateId)
);
go

CREATE TABLE dbo_Target
(
	TargetId						INTEGER NOT NULL,
	Name							TEXT NOT NULL,
	Description						TEXT NULL,
	TargetTemplateId				INTEGER NOT NULL,
	DateFrom						DATETIME NOT NULL,
	DateTo							DATETIME NOT NULL,
	TargetValue						FLOAT NOT NULL,				 -- wartosc
	CurrentValue					FLOAT NOT NULL,				 -- realizacja do danej chwili
	CurrentValueInPercent			FLOAT NOT NULL,				 -- % realizacji
	TimeInPercent					FLOAT NOT NULL,				 -- % upływu czasu
	CurrentTimeInPercent			FLOAT NOT NULL,				 -- % realizacji w czasie
	SynchState  					INTEGER NOT NULL DEFAULT 0,
    PRIMARY KEY (TargetId)
);
go

-- ----------------------------------------------------------------------
-- ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~ Ankiety ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
-- ----------------------------------------------------------------------
CREATE TABLE dbo_SurveyAnswer
(
	SurveyAnswerId		 INTEGER NOT NULL,
	SurveyQuestionId	 INTEGER NOT NULL,
    SurveyAnswerTypeId	 INTEGER NOT NULL,
    Ordinal				 INTEGER NOT NULL,
	Name				 TEXT NULL,
    DefaultValue		 TEXT NULL,
	QuestionYesId		 INTEGER NULL,
	QuestionNoId		 INTEGER NULL,
	SynchState  		 INTEGER NOT NULL DEFAULT 0,
    PRIMARY KEY (SurveyAnswerId)
);
go

CREATE TABLE dbo_Survey
(
	SurveyId 		INTEGER NOT NULL,
	Name 			TEXT NOT NULL,
	ValidFrom 		DATETIME NULL,
	ValidTo 		DATETIME NULL,
    SurveyTypeId 	INTEGER NOT NULL,
	SynchState  	INTEGER NOT NULL DEFAULT 0,
    PRIMARY KEY (SurveyId)
);
go

CREATE TABLE dbo_SurveyAssignment
(
	SurveyId		 INTEGER NOT NULL,
	AppCardId		 INTEGER NOT NULL,	-- klient(2), pracownik (24)
    SourceId		 INTEGER NOT NULL,	-- id klienta lub pracownika
	SynchState  	 INTEGER NOT NULL DEFAULT 0,
    PRIMARY KEY (SurveyId, AppCardId, SourceId)
);
go

CREATE TABLE dbo_SurveyQuestion
(
	SurveyQuestionId		 INTEGER NOT NULL,
	SurveyId				 INTEGER NOT NULL,
    Ordinal					 INTEGER NOT NULL,
	Name					 TEXT NOT NULL,
	SynchState  			 INTEGER NOT NULL DEFAULT 0,
    PRIMARY KEY(SurveyQuestionId)
);
go

CREATE TABLE dbo_SurveyResult
(
    SurveyResultId		 INTEGER NOT NULL,
	SurveyId			 INTEGER NOT NULL,
    RouteId			 	 INTEGER NOT NULL,	-- id trasówki
    AppCardId			 INTEGER NOT NULL,
    SourceId			 INTEGER NOT NULL,
    SurveyDate			 DATETIME NOT NULL,
    UserId			 	 INTEGER NOT NULL,	-- id pracownika
    ReadyToSendStatus	 INTEGER NULL,
	SynchState  		 INTEGER NOT NULL DEFAULT 0,
    PRIMARY KEY (SurveyResultId)
);
go

CREATE TABLE dbo_SurveyResultDetail
(
	SurveyResultId		 	INTEGER NOT NULL,
	SurveyAnswerId		 	INTEGER NOT NULL,
	Value				 	TEXT NOT NULL,	-- dla zdjęć jest tu klucz do tabeli AttributeValueBinary
	SynchState  		 	INTEGER NOT NULL DEFAULT 0,
    PRIMARY KEY (SurveyResultId, SurveyAnswerId)
);
go

CREATE TABLE dbo_AttributeValueBinary
(
	AttributeValueBinaryId	INTEGER NOT NULL,
	Sequence 				INTEGER NOT NULL,
	Name					TEXT NOT NULL,
	Description 			TEXT,
	FileType 				TEXT NOT NULL,
	Size 					INTEGER NOT NULL,
	Thumbnail				BLOB,	
	Value 					BLOB,
    CreateDate              DATETIME,   
	SynchState  		 	INTEGER NOT NULL DEFAULT 0,
	PRIMARY KEY (AttributeValueBinaryId)
);
go

CREATE TABLE dbo_AttributeValueBinaryCollection
(
	AttributeValueBinaryCollectionId	INTEGER NOT NULL,
	AttributeValueBinaryId 				INTEGER NOT NULL, 
	SynchState  		 				INTEGER NOT NULL DEFAULT 0,
	PRIMARY KEY (AttributeValueBinaryCollectionId, AttributeValueBinaryId)
);
go
CREATE INDEX idx_dbo_IdxAttributeValueBinaryCollectionId ON dbo_AttributeValueBinaryCollection (AttributeValueBinaryCollectionId);
go

CREATE TABLE dbo_GeolocationLog(
	GeolocationLogId					INTEGER PRIMARY KEY NOT NULL,
	GeolocationTypeId					INTEGER,
	UserId								INTEGER NOT NULL,
	Date								DATETIME NOT NULL,
	Latitude							FLOAT,
	Longitude							FLOAT,
	Ratio								INTEGER,
	GeolocationExecutionPointId			INTEGER,
	GeolocationStatusId					INTEGER,
	EntityId							INTEGER,
	EntityElementId						INTEGER,
	SynchState 							INTEGER NOT NULL DEFAULT 2						
);
go

-- Dane Pracowników konta:
CREATE TABLE dbo_UserCustomer (
	UserId 			INTEGER NOT NULL,
	CustomerId      INTEGER NOT NULL,
    IsHided         INTEGER NULL DEFAULT NULL,
	SynchState  INTEGER NOT NULL DEFAULT 0,
    PRIMARY KEY (  UserId, CustomerId  )
 );
go

-- ------------------------------------------------------

CREATE TABLE dbo_StawkaVat(
	TaxId					INTEGER NOT NULL,
	VatCode 				TEXT NOT NULL,
	Name 					TEXT NULL,
	Rate 					FLOAT NULL,
	Active 					INTEGER NULL,
	Sort 					INTEGER NULL,
	PRIMARY KEY (VatCode, Rate)
);
go

INSERT INTO dbo_StawkaVat (TaxId, VatCode, Name, Rate, Active, Sort) VALUES (1, '–', 'stawka –', 0.00, 1, 9 );
go
INSERT INTO dbo_StawkaVat (TaxId, VatCode, Name, Rate, Active, Sort) VALUES (2, '0', 'stawka 0%', 0.00, 1, 10 );
go
INSERT INTO dbo_StawkaVat (TaxId, VatCode, Name, Rate, Active, Sort) VALUES (3, '12', 'stawka 12%', 12.00, 0, 13 );
go
INSERT INTO dbo_StawkaVat (TaxId, VatCode, Name, Rate, Active, Sort) VALUES (4, '17', 'stawka 17%', 17.00, 0, 14 );
go
INSERT INTO dbo_StawkaVat (TaxId, VatCode, Name, Rate, Active, Sort) VALUES (5, '22', 'stawka 22%', 22.00, 1, 2 );
go
INSERT INTO dbo_StawkaVat (TaxId, VatCode, Name, Rate, Active, Sort) VALUES (6, '23', 'stawka 23%', 23.00, 1, 1 );
go
INSERT INTO dbo_StawkaVat (TaxId, VatCode, Name, Rate, Active, Sort) VALUES (7, '3', 'stawka 3%', 3.00, 1, 8 );
go
INSERT INTO dbo_StawkaVat (TaxId, VatCode, Name, Rate, Active, Sort) VALUES (8, '4', 'stawka 4%', 4.00, 1, 7 );
go
INSERT INTO dbo_StawkaVat (TaxId, VatCode, Name, Rate, Active, Sort) VALUES (9, '5', 'stawka 5%', 5.00, 1, 6 );
go
INSERT INTO dbo_StawkaVat (TaxId, VatCode, Name, Rate, Active, Sort) VALUES (10, '6', 'stawka 6%', 6.00, 1, 5 );
go
INSERT INTO dbo_StawkaVat (TaxId, VatCode, Name, Rate, Active, Sort) VALUES (11, '7', 'stawka 7%', 7.00, 1, 4 );
go
INSERT INTO dbo_StawkaVat (TaxId, VatCode, Name, Rate, Active, Sort) VALUES (12, '8', 'stawka 8%', 8.00, 1, 3 );
go
INSERT INTO dbo_StawkaVat (TaxId, VatCode, Name, Rate, Active, Sort) VALUES (13, 'NP', 'nie podlega', 0.00, 1, 11 );
go
INSERT INTO dbo_StawkaVat (TaxId, VatCode, Name, Rate, Active, Sort) VALUES (14, 'ZW', 'stawka zwolniona', 0.00, 1, 12 );
go

-- ------------------------------------------------------


CREATE TRIGGER
	TD_Synch_dbo_AttributeValueBinary
AFTER DELETE ON
	dbo_AttributeValueBinary
FOR EACH ROW
WHEN
	(OLD.SynchState <> 2)
BEGIN
	INSERT INTO
		SynchDeleteLog(SynchTableId, KeyValues, FieldValues)
	SELECT
		(SELECT SynchTableId FROM SynchTable WHERE name = 'dbo_AttributeValueBinary') AS synchTableId,
		OLD.AttributeValueBinaryId,null AS FieldValues;
END
go

CREATE TRIGGER 
	TI_Synch_dbo_AttributeValueBinary
AFTER INSERT ON 
	 dbo_AttributeValueBinary
FOR EACH ROW 
BEGIN 
	UPDATE 
		dbo_AttributeValueBinary
	SET 
		SynchState = 2 
	WHERE 
		AttributeValueBinaryId = NEW.AttributeValueBinaryId;
END
go

CREATE TRIGGER 
	TU_Synch_dbo_AttributeValueBinary
AFTER UPDATE ON 
	 dbo_AttributeValueBinary
FOR EACH ROW 
WHEN 
	(NEW.SynchState = 0 AND OLD.SynchState = 0) 
BEGIN 
	UPDATE 
		dbo_AttributeValueBinary
	SET 
		SynchState = 1 
	WHERE 
		AttributeValueBinaryId = NEW.AttributeValueBinaryId;
END
go


-- replication triggers for table dbo_ProductCategory
CREATE TRIGGER TI_Synch_dbo_ProductCategory
AFTER INSERT ON dbo_ProductCategory
FOR EACH ROW
BEGIN
  UPDATE dbo_ProductCategory
     SET SynchState = 2
   WHERE CategoryId = NEW.CategoryId;
END;
go


CREATE TRIGGER TU_Synch_dbo_ProductCategory
AFTER UPDATE ON dbo_ProductCategory
FOR EACH ROW
WHEN (NEW.SynchState = 0 AND OLD.SynchState = 0)
BEGIN
  UPDATE dbo_ProductCategory
     SET SynchState = 1
   WHERE CategoryId = NEW.CategoryId;
END;
go

CREATE TRIGGER TD_Synch_dbo_ProductCategory
AFTER DELETE ON dbo_ProductCategory
FOR EACH ROW
WHEN (OLD.SynchState <> 2)
BEGIN
  INSERT INTO SynchDeleteLog(SynchTableId, KeyValues, FieldValues)
  SELECT
    (SELECT SynchTableId FROM SynchTable WHERE name = 'dbo_ProductCategory') AS synchTableId,
            OLD.CategoryId,
            (
               CASE OLD.SynchState
                 WHEN 1 THEN
					IFNULL(OLD.CategoryId, '') || '|' ||
					IFNULL(LENGTH(OLD.Name) || ':' || OLD.Name, '') || '|' ||
					IFNULL(OLD.SynchState, '')
                 ELSE NULL
               END
            );
END;
go



-- replication triggers for table dbo_barcode
CREATE TRIGGER TI_Synch_dbo_Barcode
AFTER INSERT ON dbo_Barcode
FOR EACH ROW
BEGIN
  UPDATE dbo_Barcode
     SET SynchState = 2
   WHERE BarcodeId = NEW.BarcodeId;
END;
go

CREATE TRIGGER TU_Synch_dbo_Barcode
AFTER UPDATE ON dbo_Barcode
FOR EACH ROW
WHEN (NEW.SynchState = 0 AND OLD.SynchState = 0)
BEGIN
  UPDATE dbo_Barcode
     SET SynchState = 1
   WHERE BarcodeId = NEW.BarcodeId;
END;
go

CREATE TRIGGER TD_Synch_dbo_Barcode
AFTER DELETE ON dbo_Barcode
FOR EACH ROW
WHEN (OLD.SynchState <> 2)
BEGIN
  INSERT INTO SynchDeleteLog(SynchTableId, KeyValues, FieldValues)
  SELECT
    (SELECT SynchTableId FROM SynchTable WHERE name = 'dbo_Barcode') AS synchTableId,
            OLD.BarcodeId,
            (
               CASE OLD.SynchState
                 WHEN 1 THEN
					IFNULL(OLD.BarcodeId, '') || '|' ||
                    IFNULL(LENGTH(OLD.WarId) || ':' || OLD.WarId, '') || '|' ||
                    IFNULL(LENGTH(OLD.BarCode) || ':' || OLD.BarCode, '') || '|' ||
                    IFNULL(OLD.ProductId, '') || '|' ||
                    IFNULL(OLD.UnitId, '') || '|' ||
                    IFNULL(OLD.DefQuantity, '') || '|' ||
                    IFNULL(LENGTH(OLD.Description) || ':' || OLD.Description, '') || '|' ||
					IFNULL(OLD.SynchState, '')
                 ELSE NULL
               END
            );
END;
go

-- replication triggers for table dbo_UserCustomer

CREATE TRIGGER TI_Synch_dbo_UserCustomer
AFTER INSERT ON dbo_UserCustomer
FOR EACH ROW
BEGIN
  UPDATE dbo_UserCustomer
     SET SynchState = 2
   WHERE UserId = NEW.UserId and CustomerId = NEW.CustomerId;
END;
go


CREATE TRIGGER TU_Synch_dbo_UserCustomer
AFTER UPDATE ON dbo_UserCustomer
FOR EACH ROW
WHEN (NEW.SynchState = 0 AND OLD.SynchState = 0)
BEGIN
  UPDATE dbo_UserCustomer
     SET SynchState = 1
      WHERE UserId = NEW.UserId and CustomerId = NEW.CustomerId;
END;
go

CREATE TRIGGER TD_Synch_dbo_UserCustomer
AFTER DELETE ON dbo_UserCustomer
FOR EACH ROW
WHEN (OLD.SynchState <> 2)
BEGIN
  INSERT INTO SynchDeleteLog(SynchTableId, KeyValues, FieldValues)
  SELECT
    (SELECT SynchTableId FROM SynchTable WHERE name = 'dbo_UserCustomer') AS synchTableId,
            OLD.UserId || '|' || OLD.CustomerId,
            (
               CASE OLD.SynchState
                 WHEN 1 THEN
					IFNULL(OLD.UserId, '') || '|' ||
					IFNULL(OLD.CustomerId, '') || '|' ||
					IFNULL(OLD.IsHided, '') || '|' ||
					IFNULL(OLD.SynchState, '')
                 ELSE NULL
               END
            );
END;
go

-- replication triggers for table dbo_Unit
CREATE TRIGGER TI_Synch_dbo_Unit
AFTER INSERT ON dbo_Unit
FOR EACH ROW
BEGIN
  UPDATE dbo_Unit
     SET SynchState = 2
   WHERE UnitId = NEW.UnitId;
END;
go


CREATE TRIGGER TU_Synch_dbo_Unit
AFTER UPDATE ON dbo_Unit
FOR EACH ROW
WHEN (NEW.SynchState = 0 AND OLD.SynchState = 0)
BEGIN
  UPDATE dbo_Unit
     SET SynchState = 1
   WHERE UnitId = NEW.UnitId;
END;
go

CREATE TRIGGER TD_Synch_dbo_Unit
AFTER DELETE ON dbo_Unit
FOR EACH ROW
WHEN (OLD.SynchState <> 2)
BEGIN
  INSERT INTO SynchDeleteLog(SynchTableId, KeyValues, FieldValues)
  SELECT
    (SELECT SynchTableId FROM SynchTable WHERE name = 'dbo_Unit') AS synchTableId,
            OLD.UnitId,
            (
               CASE OLD.SynchState
                 WHEN 1 THEN
					IFNULL(OLD.UnitId, '') || '|' ||
					IFNULL(LENGTH(OLD.Name) || ':' || OLD.Name, '') || '|' ||
					IFNULL(OLD.Divisible, '') || '|' ||
					IFNULL(OLD.SynchState, '')
                 ELSE NULL
               END
            );
END;
go

-- replication triggers for table dbo_ProductUnit
CREATE TRIGGER TI_Synch_dbo_ProductUnit
AFTER INSERT ON dbo_ProductUnit
FOR EACH ROW
BEGIN
  UPDATE dbo_ProductUnit
     SET SynchState = 2
   WHERE ProductUniqueId = NEW.ProductUniqueId
		AND UnitId = NEW.UnitId;
END;
go


CREATE TRIGGER TU_Synch_dbo_ProductUnit
AFTER UPDATE ON dbo_ProductUnit
FOR EACH ROW
WHEN (NEW.SynchState = 0 AND OLD.SynchState = 0)
BEGIN
  UPDATE dbo_ProductUnit
     SET SynchState = 1
   WHERE ProductUniqueId = NEW.ProductUniqueId
		AND UnitId = NEW.UnitId;
END;
go

CREATE TRIGGER TD_Synch_dbo_ProductUnit
AFTER DELETE ON dbo_ProductUnit
FOR EACH ROW
WHEN (OLD.SynchState <> 2)
BEGIN
  INSERT INTO SynchDeleteLog(SynchTableId, KeyValues, FieldValues)
  SELECT
    (SELECT SynchTableId FROM SynchTable WHERE name = 'dbo_ProductUnit') AS synchTableId,
            OLD.ProductUniqueId || '|' || OLD.UnitId,
            (
               CASE OLD.SynchState
                 WHEN 1 THEN
					IFNULL(OLD.ProductUniqueId, '') || '|' ||
					IFNULL(OLD.UnitId, '') || '|' ||
					IFNULL(OLD.ConversionRate, '') || '|' ||
					IFNULL(OLD.Divisible, '') || '|' ||
					IFNULL(OLD.SynchState, '')
                 ELSE NULL
               END
            );
END;
go

-- replication triggers for table dbo_Product
CREATE TRIGGER TI_Synch_dbo_Product
AFTER INSERT ON dbo_Product
FOR EACH ROW
BEGIN
  UPDATE dbo_Product
     SET SynchState = 2
   WHERE ProductId = NEW.ProductId;
END;
go

CREATE TRIGGER TD_Synch_dbo_Product
AFTER DELETE ON dbo_Product
FOR EACH ROW
WHEN (OLD.SynchState <> 2)
BEGIN
  INSERT INTO SynchDeleteLog(SynchTableId, KeyValues, FieldValues)
  SELECT
    (SELECT SynchTableId FROM SynchTable WHERE name = 'dbo_Product') AS synchTableId,
            OLD.ProductId,
            (
               CASE OLD.SynchState
                 WHEN 1 THEN
					IFNULL(OLD.ProductId, '') || '|' ||
					IFNULL(OLD.CategoryId, '') || '|' ||
					IFNULL(LENGTH(OLD.TaxSale) || ':' || OLD.TaxSale, '') || '|' ||
					IFNULL(OLD.TaxSaleValue, '') || '|' ||
					IFNULL(LENGTH(OLD.TaxPurchase) || ':' || OLD.TaxPurchase, '') || '|' ||
					IFNULL(OLD.TaxPurchaseValue, '') || '|' ||
					IFNULL(OLD.ProductType, '') || '|' ||
					IFNULL(LENGTH(OLD.Name) || ':' || OLD.Name, '') || '|' ||
					IFNULL(LENGTH(OLD.Name2) || ':' || OLD.Name2, '') || '|' ||
					IFNULL(LENGTH(OLD.OriginalName) || ':' || OLD.OriginalName, '') || '|' ||
					IFNULL(LENGTH(OLD.CatalogIndex) || ':' || OLD.CatalogIndex, '') || '|' ||
					IFNULL(LENGTH(OLD.TradeIndex) || ':' || OLD.TradeIndex, '') || '|' ||
					IFNULL(LENGTH(OLD.SWWKU) || ':' || OLD.SWWKU, '') || '|' ||
					IFNULL(LENGTH(OLD.PKWIU) || ':' || OLD.PKWIU, '') || '|' ||
					IFNULL(LENGTH(OLD.Localisation) || ':' || OLD.Localisation, '') || '|' ||
					IFNULL(OLD.StockChange, '') || '|' ||
					IFNULL(OLD.Discountable, '') || '|' ||
					IFNULL(OLD.PromoDateBeg, '') || '|' ||
					IFNULL(OLD.PromoDateEnd, '') || '|' ||
					IFNULL(OLD.PromoNetPrice, '') || '|' ||
					IFNULL(OLD.PromoGrossPrice, '') || '|' ||
					IFNULL(OLD.PromoPriceDiscountable, '') || '|' ||
					IFNULL(LENGTH(OLD.Warning) || ':' || OLD.Warning, '') || '|' ||
					IFNULL(OLD.ShowWarning, '') || '|' ||
					IFNULL(LENGTH(OLD.Description) || ':' || OLD.Description, '') || '|' ||
					IFNULL(LENGTH(OLD.Remarks) || ':' || OLD.Remarks, '') || '|' ||
					IFNULL(OLD.WarehouseLock, '') || '|' ||
					IFNULL(LENGTH(OLD.BarCode) || ':' || OLD.BarCode, '') || '|' ||
					IFNULL(OLD.CategoryTreeId, '') || '|' ||
					IFNULL(OLD.PromoDiscountPercent, '') || '|' ||					
					IFNULL(OLD.SynchState, '')
                 ELSE NULL
               END
            );
END;
go

-- replication triggers for table dbo_ProductWarehouse
CREATE TRIGGER TI_Synch_dbo_ProductWarehouse
AFTER INSERT ON dbo_ProductWarehouse
FOR EACH ROW
BEGIN
  UPDATE dbo_ProductWarehouse
     SET SynchState = 2
   WHERE ProductUniqueId = NEW.ProductUniqueId;
END;
go

CREATE TRIGGER TD_Synch_dbo_ProductWarehouse
AFTER DELETE ON dbo_ProductWarehouse
FOR EACH ROW
WHEN (OLD.SynchState <> 2)
BEGIN
  INSERT INTO SynchDeleteLog(SynchTableId, KeyValues, FieldValues)
  SELECT
    (SELECT SynchTableId FROM SynchTable WHERE name = 'dbo_ProductWarehouse') AS synchTableId,
            OLD.ProductUniqueId,
            (
               CASE OLD.SynchState
                 WHEN 1 THEN
					IFNULL(OLD.ProductUniqueId, '') || '|' ||
					IFNULL(OLD.ProductId, '') || '|' ||
					IFNULL(OLD.WarehouseId, '') || '|' ||
					IFNULL(OLD.Stock, '') || '|' ||
					IFNULL(OLD.Reserved, '') || '|' ||
					IFNULL(OLD.DefaultPriceId, '') || '|' ||
					IFNULL(OLD.UnitId, '') || '|' ||
					IFNULL(OLD.PurchaseUnitId, '') || '|' ||
					IFNULL(OLD.SaleUnitId, '') || '|' ||
					IFNULL(OLD.PurchaseNetPrice, '') || '|' ||
					IFNULL(OLD.PurchaseGrossPrice, '') || '|' ||
					IFNULL(OLD.LocalStock, '') || '|' ||
					IFNULL(OLD.LocalReserved, '') || '|' ||
					IFNULL(OLD.StockMinimum, '') || '|' ||
					IFNULL(OLD.StockMaximum, '') || '|' ||
					IFNULL(OLD.MinMarkUp, '') || '|' ||
					IFNULL(OLD.SynchState, '')
                 ELSE NULL
               END
            );
END;
go


-- replication triggers for table dbo_Price
CREATE TRIGGER TI_Synch_dbo_Price
AFTER INSERT ON dbo_Price
FOR EACH ROW
BEGIN
  UPDATE dbo_Price
     SET SynchState = 2
   WHERE PriceId = NEW.PriceId;
END;
go


CREATE TRIGGER TU_Synch_dbo_Price
AFTER UPDATE ON dbo_Price
FOR EACH ROW
WHEN (NEW.SynchState = 0 AND OLD.SynchState = 0)
BEGIN
  UPDATE dbo_Price
     SET SynchState = 1
   WHERE PriceId = NEW.PriceId;
END;
go

CREATE TRIGGER TD_Synch_dbo_Price
AFTER DELETE ON dbo_Price
FOR EACH ROW
WHEN (OLD.SynchState <> 2)
BEGIN
  INSERT INTO SynchDeleteLog(SynchTableId, KeyValues, FieldValues)
  SELECT
    (SELECT SynchTableId FROM SynchTable WHERE name = 'dbo_Price') AS synchTableId,
            OLD.PriceId,
            (
               CASE OLD.SynchState
                 WHEN 1 THEN
					IFNULL(OLD.PriceId, '') || '|' ||
					IFNULL(LENGTH(OLD.Name) || ':' || OLD.Name, '') || '|' ||
					IFNULL(OLD.SynchState, '')
                 ELSE NULL
               END
            );
END;
go

-- replication triggers for table dbo_ProductPrice
CREATE TRIGGER TI_Synch_dbo_ProductPrice
AFTER INSERT ON dbo_ProductPrice
FOR EACH ROW
BEGIN
  UPDATE dbo_ProductPrice
     SET SynchState = 2
   WHERE ProductUniqueId = NEW.ProductUniqueId
		AND PriceId = NEW.PriceId;
END;
go


CREATE TRIGGER TU_Synch_dbo_ProductPrice
AFTER UPDATE ON dbo_ProductPrice
FOR EACH ROW
WHEN (NEW.SynchState = 0 AND OLD.SynchState = 0)
BEGIN
  UPDATE dbo_ProductPrice
     SET SynchState = 1
   WHERE ProductUniqueId = NEW.ProductUniqueId
		AND PriceId = NEW.PriceId;
END;
go

CREATE TRIGGER TD_Synch_dbo_ProductPrice
AFTER DELETE ON dbo_ProductPrice
FOR EACH ROW
WHEN (OLD.SynchState <> 2)
BEGIN
  INSERT INTO SynchDeleteLog(SynchTableId, KeyValues, FieldValues)
  SELECT
    (SELECT SynchTableId FROM SynchTable WHERE name = 'dbo_ProductPrice') AS synchTableId,
            OLD.ProductUniqueId || '|' || OLD.PriceId,
            (
               CASE OLD.SynchState
                 WHEN 1 THEN
                   IFNULL(OLD.ProductUniqueId, '') || '|' ||
                   IFNULL(OLD.PriceId, '') || '|' ||
				   IFNULL(OLD.NetPrice, '') || '|' ||
				   IFNULL(OLD.GrossPrice, '') || '|' ||
                   IFNULL(OLD.SynchState, '')
                 ELSE NULL
               END
            );
END;
go

-- replication triggers for table dbo_Company
CREATE TRIGGER TI_Synch_dbo_Company
AFTER INSERT ON dbo_Company
FOR EACH ROW
BEGIN
  UPDATE dbo_Company
     SET SynchState = 2
   WHERE CompanyId = NEW.CompanyId;
END;
go


CREATE TRIGGER TU_Synch_dbo_Company
AFTER UPDATE ON dbo_Company
FOR EACH ROW
WHEN (NEW.SynchState = 0 AND OLD.SynchState = 0)
BEGIN
  UPDATE dbo_Company
     SET SynchState = 1
   WHERE CompanyId = NEW.CompanyId;
END;
go

CREATE TRIGGER TD_Synch_dbo_Company
AFTER DELETE ON dbo_Company
FOR EACH ROW
WHEN (OLD.SynchState <> 2)
BEGIN
  INSERT INTO SynchDeleteLog(SynchTableId, KeyValues, FieldValues)
  SELECT
    (SELECT SynchTableId FROM SynchTable WHERE name = 'dbo_Company') AS synchTableId,
            OLD.CompanyId,
            (
               CASE OLD.SynchState
                 WHEN 1 THEN
                   IFNULL(OLD.CompanyId, '') || '|' ||
				   IFNULL(LENGTH(OLD.Name) || ':' || OLD.Name, '') || '|' ||
				   IFNULL(LENGTH(OLD.FullName) || ':' || OLD.FullName, '') || '|' ||
				   IFNULL(LENGTH(OLD.Nip) || ':' || OLD.Nip, '') || '|' ||
				   IFNULL(LENGTH(OLD.Regon) || ':' || OLD.Regon, '') || '|' ||
				   IFNULL(LENGTH(OLD.PostalCode) || ':' || OLD.PostalCode, '') || '|' ||
				   IFNULL(LENGTH(OLD.City) || ':' || OLD.City, '') || '|' ||
				   IFNULL(LENGTH(OLD.Street) || ':' || OLD.Street, '') || '|' ||
				   IFNULL(LENGTH(OLD.LocumNumber) || ':' || OLD.LocumNumber, '') || '|' ||
				   IFNULL(LENGTH(OLD.BankName) || ':' || OLD.BankName, '') || '|' ||
				   IFNULL(LENGTH(OLD.AccountNumber) || ':' || OLD.AccountNumber, '') || '|' ||
                   IFNULL(OLD.DefaultTillId, '') || '|' ||
                   IFNULL(LENGTH(OLD.PrintHeader) || ':' || OLD.PrintHeader, '') || '|' ||
                   IFNULL(LENGTH(OLD.PrintFooter) || ':' || OLD.PrintFooter, '') || '|' ||
                   IFNULL(OLD.SynchState, '')
                 ELSE NULL
               END
            );
END;
go

-- replication triggers for table dbo_IndividualPrice
CREATE TRIGGER TI_Synch_dbo_IndividualPrice
AFTER INSERT ON dbo_IndividualPrice
FOR EACH ROW
BEGIN
  UPDATE dbo_IndividualPrice
     SET SynchState = 2
   WHERE SourceType = NEW.SourceType
		AND SourceId = NEW.SourceId
		AND ProductUniqueId = NEW.ProductUniqueId;
END;
go

CREATE TRIGGER TD_Synch_dbo_IndividualPrice
AFTER DELETE ON dbo_IndividualPrice
FOR EACH ROW
WHEN (OLD.SynchState <> 2)
BEGIN
  INSERT INTO SynchDeleteLog(SynchTableId, KeyValues, FieldValues)
  SELECT
    (SELECT SynchTableId FROM SynchTable WHERE name = 'dbo_IndividualPrice') AS synchTableId,
            OLD.SourceType || '|' || OLD.SourceId || '|' || OLD.ProductUniqueId,
            (
               CASE OLD.SynchState
                 WHEN 1 THEN
                   IFNULL(OLD.SourceType, '') || '|' ||
                   IFNULL(OLD.SourceId, '') || '|' ||
                   IFNULL(OLD.ProductUniqueId, '') || '|' ||
                   IFNULL(LENGTH(OLD.IndividualIndex) || ':' || OLD.IndividualIndex, '') || '|' ||
                   IFNULL(LENGTH(OLD.IndividualName) || ':' || OLD.IndividualName, '') || '|' ||
                   IFNULL(OLD.PriceMode, '') || '|' ||
                   IFNULL(OLD.PriceId, '') || '|' ||
                   IFNULL(OLD.Discount, '') || '|' ||
                   IFNULL(OLD.NetPrice, '') || '|' ||
                   IFNULL(OLD.GrossPrice, '') || '|' ||
                   IFNULL(OLD.SynchState, '')
                 ELSE NULL
               END
            );
END;
go

-- replication triggers for table dbo_AttributeValue
CREATE TRIGGER TI_Synch_dbo_AttributeValue
AFTER INSERT ON dbo_AttributeValue
FOR EACH ROW
BEGIN
  UPDATE dbo_AttributeValue
     SET SynchState = 2
   WHERE AppCardId = NEW.AppCardId
   AND SourceId = NEW.SourceId
   AND AttributeId = NEW.AttributeId;
END;
go

CREATE TRIGGER TU_Synch_dbo_AttributeValue
AFTER UPDATE ON dbo_AttributeValue
FOR EACH ROW
WHEN (NEW.SynchState = 0 AND OLD.SynchState = 0)
BEGIN
  UPDATE dbo_AttributeValue
     SET SynchState = 1
   WHERE AppCardId = NEW.AppCardId
   AND SourceId = NEW.SourceId
   AND AttributeId = NEW.AttributeId;
END;
go

CREATE TRIGGER TD_Synch_dbo_AttributeValue
AFTER DELETE ON dbo_AttributeValue
FOR EACH ROW
WHEN (OLD.SynchState <> 2)
BEGIN
  INSERT INTO SynchDeleteLog(SynchTableId, KeyValues, FieldValues)
  SELECT
    (SELECT SynchTableId FROM SynchTable WHERE name = 'dbo_AttributeValue') AS synchTableId,
            OLD.AppCardId || '|' || OLD.SourceId || '|' || OLD.AttributeId,
            (
               CASE OLD.SynchState
                 WHEN 1 THEN
                   IFNULL(LENGTH(OLD.Value) || ':' || OLD.Value, '') || '|' ||
				   IFNULL(OLD.AttributeValueBinaryId, '') || '|' ||
				   IFNULL(OLD.AttributeValueBinaryCollectionId, '') || '|' ||
				   IFNULL(LENGTH(OLD.CatalogIndex) || ':' || OLD.CatalogIndex, '') || '|' ||
                   IFNULL(OLD.SynchState, '')
                 ELSE NULL
               END
            );
END;
go

-- replication triggers for table dbo_Bill
CREATE TRIGGER TI_Synch_dbo_Bill
AFTER INSERT ON dbo_Bill
FOR EACH ROW
BEGIN
  UPDATE dbo_Bill
     SET SynchState = 2
   WHERE BillId = NEW.BillId;
END;
go

CREATE TRIGGER TU_Synch_dbo_Bill
AFTER UPDATE ON dbo_Bill
FOR EACH ROW
WHEN (NEW.SynchState = 0 AND OLD.SynchState = 0)
BEGIN
  UPDATE dbo_Bill
     SET SynchState = 1
   WHERE BillId = NEW.BillId;
END;
go

CREATE TRIGGER TD_Synch_dbo_Bill
AFTER DELETE ON dbo_Bill
FOR EACH ROW
WHEN (OLD.SynchState <> 2)
BEGIN
  INSERT INTO SynchDeleteLog(SynchTableId, KeyValues, FieldValues)
  SELECT
    (SELECT SynchTableId FROM SynchTable WHERE name = 'dbo_Bill') AS synchTableId,
            OLD.BillId,
            (
               CASE OLD.SynchState
                 WHEN 1 THEN
                   IFNULL(OLD.Type, '') || '|' ||
                   IFNULL(OLD.PayerId, '') || '|' ||
                   IFNULL(OLD.DocumentId, '') || '|' ||
                   IFNULL(LENGTH(OLD.Number) || ':' || OLD.Number, '') || '|' ||
                   IFNULL(OLD.IssueDate, '') || '|' ||
                   IFNULL(OLD.CreateDate, '') || '|' ||
                   IFNULL(OLD.PaymentDate, '') || '|' ||
                   IFNULL(OLD.WorthGross, '') || '|' ||
                   IFNULL(OLD.WorthPayments, '') || '|' ||
                   IFNULL(OLD.Paid, '') || '|' ||
                   IFNULL(OLD.UserId, '') || '|' ||
                   IFNULL(OLD.SynchState, '')
                 ELSE NULL
               END
            );
END;
go

-- replication triggers for table dbo_Customer
CREATE TRIGGER TI_Synch_dbo_Customer
AFTER INSERT ON dbo_Customer
FOR EACH ROW
BEGIN
  UPDATE dbo_Customer
     SET SynchState = 2
   WHERE CustomerId = NEW.CustomerId;
END;
go

CREATE TRIGGER TU_Synch_dbo_Customer
AFTER UPDATE ON dbo_Customer
FOR EACH ROW
WHEN (NEW.SynchState = 0 AND OLD.SynchState = 0)
BEGIN
  UPDATE dbo_Customer
     SET SynchState = 1
   WHERE CustomerId = NEW.CustomerId;
END;
go

CREATE TRIGGER TD_Synch_dbo_Customer
AFTER DELETE ON dbo_Customer
FOR EACH ROW
WHEN (OLD.SynchState <> 2)
BEGIN
  INSERT INTO SynchDeleteLog(SynchTableId, KeyValues, FieldValues)
  SELECT
    (SELECT SynchTableId FROM SynchTable WHERE name = 'dbo_Customer') AS synchTableId,
            OLD.CustomerId,
            (
               CASE OLD.SynchState
                 WHEN 1 THEN
                   IFNULL(OLD.PayerId, '') || '|' ||
                   IFNULL(OLD.CustomerStatus, '') || '|' ||
                   IFNULL(OLD.GroupId, '') || '|' ||
                   IFNULL(OLD.ClassificationId, '') || '|' ||
                   IFNULL(LENGTH(OLD.Name) || ':' || OLD.Name, '') || '|' ||
                   IFNULL(LENGTH(OLD.FullName) || ':' || OLD.FullName, '') || '|' ||
                   IFNULL(LENGTH(OLD.DistinguishFeature) || ':' || OLD.DistinguishFeature, '') || '|' ||
                   IFNULL(LENGTH(OLD.PESEL) || ':' || OLD.PESEL, '') || '|' ||
                   IFNULL(LENGTH(OLD.NIP) || ':' || OLD.NIP, '') || '|' ||
                   IFNULL(LENGTH(OLD.NIPL) || ':' || OLD.NIPL, '') || '|' ||
                   IFNULL(LENGTH(OLD.REGON) || ':' || OLD.REGON, '') || '|' ||
                   IFNULL(OLD.Recipient, '') || '|' ||
                   IFNULL(OLD.Supplier, '') || '|' ||
                   IFNULL(OLD.TaxPayer, '') || '|' ||
                   IFNULL(OLD.PersDataAgreement, '') || '|' ||
                   IFNULL(OLD.RegionId, '') || '|' ||
                   IFNULL(LENGTH(OLD.PostalCode) || ':' || OLD.PostalCode, '') || '|' ||
                   IFNULL(LENGTH(OLD.City) || ':' || OLD.City, '') || '|' ||
                   IFNULL(LENGTH(OLD.Street) || ':' || OLD.Street, '') || '|' ||
                   IFNULL(LENGTH(OLD.LocumNumber) || ':' || OLD.LocumNumber, '') || '|' ||
                   IFNULL(LENGTH(OLD.Homepage) || ':' || OLD.Homepage, '') || '|' ||
                   IFNULL(LENGTH(OLD.Email) || ':' || OLD.Email, '') || '|' ||
                   IFNULL(OLD.TradeCredit, '') || '|' ||
                   IFNULL(OLD.DaysDelay, '') || '|' ||
                   IFNULL(OLD.SaleLock, '') || '|' ||
                   IFNULL(OLD.DefDiscount, '') || '|' ||
                   IFNULL(OLD.DefPaymentForm, '') || '|' ||
                   IFNULL(OLD.TermReceivables, '') || '|' ||
                   IFNULL(OLD.TermLiabilities, '') || '|' ||
                   IFNULL(OLD.ShowWarning, '') || '|' ||
                   IFNULL(LENGTH(OLD.Warning) || ':' || OLD.Warning, '') || '|' ||
                   IFNULL(LENGTH(OLD.Remarks) || ':' || OLD.Remarks, '') || '|' ||
                   IFNULL(OLD.DeleteProposal, '') || '|' ||
                   IFNULL(OLD.UserId, '') || '|' ||
                   IFNULL(OLD.WarehouseLock, '') || '|' ||
                   IFNULL(OLD.RouteKindId, '') || '|' ||
				   IFNULL(OLD.Latitude, '') || '|' ||
				   IFNULL(OLD.Longitude, '') || '|' ||
				   IFNULL(OLD.SystemId, '') || '|' ||
				   IFNULL(OLD.InPromotion, '') || '|' ||				   
                   IFNULL(OLD.SynchState, '')
                 ELSE NULL
               END
            );
END;
go

-- replication triggers for table dbo_CustomerBankAccount
CREATE TRIGGER TI_Synch_dbo_CustomerBankAccount
AFTER INSERT ON dbo_CustomerBankAccount
FOR EACH ROW
BEGIN
  UPDATE dbo_CustomerBankAccount
     SET SynchState = 2
   WHERE AccountId = NEW.AccountId;
END;
go

CREATE TRIGGER TU_Synch_dbo_CustomerBankAccount
AFTER UPDATE ON dbo_CustomerBankAccount
FOR EACH ROW
WHEN (NEW.SynchState = 0 AND OLD.SynchState = 0)
BEGIN
  UPDATE dbo_CustomerBankAccount
     SET SynchState = 1
   WHERE AccountId = NEW.AccountId;
END;
go

CREATE TRIGGER TD_Synch_dbo_CustomerBankAccount
AFTER DELETE ON dbo_CustomerBankAccount
FOR EACH ROW
WHEN (OLD.SynchState <> 2)
BEGIN
  INSERT INTO SynchDeleteLog(SynchTableId, KeyValues, FieldValues)
  SELECT
    (SELECT SynchTableId FROM SynchTable WHERE name = 'dbo_CustomerBankAccount') AS synchTableId,
            OLD.AccountId,
            (
               CASE OLD.SynchState
                 WHEN 1 THEN
                   IFNULL(OLD.CustomerId, '') || '|' ||
                   IFNULL(LENGTH(OLD.BankName) || ':' || OLD.BankName, '') || '|' ||
                   IFNULL(LENGTH(OLD.BankNumber) || ':' || OLD.BankNumber, '') || '|' ||
                   IFNULL(LENGTH(OLD.AccountNumber) || ':' || OLD.AccountNumber, '') || '|' ||
                   IFNULL(OLD.IsDefault, '') || '|' ||
                   IFNULL(LENGTH(OLD.Description) || ':' || OLD.Description, '') || '|' ||
                   IFNULL(OLD.SynchState, '')
                 ELSE NULL
               END
            );
END;
go

-- replication triggers for table dbo_CustomerContact
CREATE TRIGGER TI_Synch_dbo_CustomerContact
AFTER INSERT ON dbo_CustomerContact
FOR EACH ROW
BEGIN
  UPDATE dbo_CustomerContact
     SET SynchState = 2
   WHERE ContactId = NEW.ContactId;
END;
go

CREATE TRIGGER TU_Synch_dbo_CustomerContact
AFTER UPDATE ON dbo_CustomerContact
FOR EACH ROW
WHEN (NEW.SynchState = 0 AND OLD.SynchState = 0)
BEGIN
  UPDATE dbo_CustomerContact
     SET SynchState = 1
   WHERE ContactId = NEW.ContactId;
END;
go

CREATE TRIGGER TD_Synch_dbo_CustomerContact
AFTER DELETE ON dbo_CustomerContact
FOR EACH ROW
WHEN (OLD.SynchState <> 2)
BEGIN
  INSERT INTO SynchDeleteLog(SynchTableId, KeyValues, FieldValues)
  SELECT
    (SELECT SynchTableId FROM SynchTable WHERE name = 'dbo_CustomerContact') AS synchTableId,
            OLD.ContactId,
            (
               CASE OLD.SynchState
                 WHEN 1 THEN
                   IFNULL(OLD.CustomerId, '') || '|' ||
                   IFNULL(OLD.IsDefault, '') || '|' ||
                   IFNULL(LENGTH(OLD.Position) || ':' || OLD.Position, '') || '|' ||
                   IFNULL(LENGTH(OLD.FirstName) || ':' || OLD.FirstName, '') || '|' ||
                   IFNULL(LENGTH(OLD.LastName) || ':' || OLD.LastName, '') || '|' ||
                   IFNULL(LENGTH(OLD.PhoneNo) || ':' || OLD.PhoneNo, '') || '|' ||
                   IFNULL(LENGTH(OLD.CellPhoneNo) || ':' || OLD.CellPhoneNo, '') || '|' ||
                   IFNULL(LENGTH(OLD.Fax) || ':' || OLD.Fax, '') || '|' ||
                   IFNULL(LENGTH(OLD.Email) || ':' || OLD.Email, '') || '|' ||
                   IFNULL(LENGTH(OLD.Remarks) || ':' || OLD.Remarks, '') || '|' ||
                   IFNULL(OLD.SynchState, '')
                 ELSE NULL
               END
            );
END;
go

-- replication triggers for table dbo_DayReport
CREATE TRIGGER TI_Synch_dbo_DayReport
AFTER INSERT ON dbo_DayReport
FOR EACH ROW
BEGIN
  UPDATE dbo_DayReport
     SET SynchState = 2
   WHERE DayReportId = NEW.DayReportId;
END;
go

CREATE TRIGGER TU_Synch_dbo_DayReport
AFTER UPDATE ON dbo_DayReport
FOR EACH ROW
WHEN (NEW.SynchState = 0 AND OLD.SynchState = 0)
BEGIN
  UPDATE dbo_DayReport
     SET SynchState = 1
   WHERE DayReportId = NEW.DayReportId;
END;
go

CREATE TRIGGER TD_Synch_dbo_DayReport
AFTER DELETE ON dbo_DayReport
FOR EACH ROW
WHEN (OLD.SynchState <> 2)
BEGIN
  INSERT INTO SynchDeleteLog(SynchTableId, KeyValues, FieldValues)
  SELECT
    (SELECT SynchTableId FROM SynchTable WHERE name = 'dbo_DayReport') AS synchTableId,
            OLD.DayReportId,
            (
               CASE OLD.SynchState
                 WHEN 1 THEN
                   IFNULL(OLD.UserId, '') || '|' ||
                   IFNULL(OLD.ReportDate, '') || '|' ||
                   IFNULL(OLD.MileageStart, '') || '|' ||
                   IFNULL(OLD.MileageStop, '') || '|' ||
                   IFNULL(OLD.CarChanged, '') || '|' ||
                   IFNULL(OLD.Closed, '') || '|' ||
                   IFNULL(OLD.SynchState, '')
                 ELSE NULL
               END
            );
END;
go

-- replication triggers for table dbo_DocNumeration
CREATE TRIGGER TI_Synch_dbo_DocNumeration
AFTER INSERT ON dbo_DocNumeration
FOR EACH ROW
BEGIN
  UPDATE dbo_DocNumeration
     SET SynchState = 2
   WHERE UserId = NEW.UserId
   AND DocumentCategory = NEW.DocumentCategory
   AND DocumentType = NEW.DocumentType
   AND ResourceId = NEW.ResourceId
   AND Period = NEW.Period;
END;
go

CREATE TRIGGER TU_Synch_dbo_DocNumeration
AFTER UPDATE ON dbo_DocNumeration
FOR EACH ROW
WHEN (NEW.SynchState = 0 AND OLD.SynchState = 0)
BEGIN
  UPDATE dbo_DocNumeration
     SET SynchState = 1
   WHERE UserId = NEW.UserId
   AND DocumentCategory = NEW.DocumentCategory
   AND DocumentType = NEW.DocumentType
   AND ResourceId = NEW.ResourceId
   AND Period = NEW.Period;
END;
go

CREATE TRIGGER TD_Synch_dbo_DocNumeration
AFTER DELETE ON dbo_DocNumeration
FOR EACH ROW
WHEN (OLD.SynchState <> 2)
BEGIN
  INSERT INTO SynchDeleteLog(SynchTableId, KeyValues, FieldValues)
  SELECT
    (SELECT SynchTableId FROM SynchTable WHERE name = 'dbo_DocNumeration') AS synchTableId,
            OLD.UserId || '|' || OLD.DocumentCategory || '|' || OLD.DocumentType || '|' || OLD.ResourceId || '|' || OLD.Period,
            (
               CASE OLD.SynchState
                 WHEN 1 THEN
                   IFNULL(OLD.NextValue, '') || '|' ||
                   IFNULL(OLD.SynchState, '')
                 ELSE NULL
               END
            );
END;
go

-- replication triggers for table dbo_DocOrderProducer
CREATE TRIGGER TI_Synch_dbo_DocOrderProducer
AFTER INSERT ON dbo_DocOrderProducer
FOR EACH ROW
BEGIN
  UPDATE dbo_DocOrderProducer
     SET SynchState = 2
   WHERE DocumentId = NEW.DocumentId;
END;
go

CREATE TRIGGER TU_Synch_dbo_DocOrderProducer
AFTER UPDATE ON dbo_DocOrderProducer
FOR EACH ROW
WHEN (NEW.SynchState = 0 AND OLD.SynchState = 0)
BEGIN
  UPDATE dbo_DocOrderProducer
     SET SynchState = 1
   WHERE DocumentId = NEW.DocumentId;
END;
go

CREATE TRIGGER TD_Synch_dbo_DocOrderProducer
AFTER DELETE ON dbo_DocOrderProducer
FOR EACH ROW
WHEN (OLD.SynchState <> 2)
BEGIN
  INSERT INTO SynchDeleteLog(SynchTableId, KeyValues, FieldValues)
  SELECT
    (SELECT SynchTableId FROM SynchTable WHERE name = 'dbo_DocOrderProducer') AS synchTableId,
            OLD.DocumentId,
            (
               CASE OLD.SynchState
                 WHEN 1 THEN
                   IFNULL(LENGTH(OLD.NumOrderProd) || ':' || OLD.NumOrderProd, '') || '|' ||
                   IFNULL(OLD.CustomerId, '') || '|' ||
                   IFNULL(OLD.OrderDate, '') || '|' ||
                   IFNULL(OLD.PaymentFormId, '') || '|' ||
                   IFNULL(OLD.PaymentTerm, '') || '|' ||
                   IFNULL(OLD.Status, '') || '|' ||
                   IFNULL(LENGTH(OLD.Remarks) || ':' || OLD.Remarks, '') || '|' ||
                   IFNULL(OLD.WarehouseId, '') || '|' ||
                   IFNULL(OLD.AlertPointer, '') || '|' ||
                   IFNULL(OLD.SynchState, '')
                 ELSE NULL
               END
            );
END;
go

-- replication triggers for table dbo_DocOrderProducer_Order
CREATE TRIGGER TI_Synch_dbo_DocOrderProducer_Order
AFTER INSERT ON dbo_DocOrderProducer_Order
FOR EACH ROW
BEGIN
  UPDATE dbo_DocOrderProducer_Order
     SET SynchState = 2
   WHERE DocOrderProducerId = NEW.DocOrderProducerId
   AND OrderId = NEW.OrderId;
END;
go

CREATE TRIGGER TU_Synch_dbo_DocOrderProducer_Order
AFTER UPDATE ON dbo_DocOrderProducer_Order
FOR EACH ROW
WHEN (NEW.SynchState = 0 AND OLD.SynchState = 0)
BEGIN
  UPDATE dbo_DocOrderProducer_Order
     SET SynchState = 1
   WHERE DocOrderProducerId = NEW.DocOrderProducerId
   AND OrderId = NEW.OrderId;
END;
go

CREATE TRIGGER TD_Synch_dbo_DocOrderProducer_Order
AFTER DELETE ON dbo_DocOrderProducer_Order
FOR EACH ROW
WHEN (OLD.SynchState <> 2)
BEGIN
  INSERT INTO SynchDeleteLog(SynchTableId, KeyValues, FieldValues)
  SELECT
    (SELECT SynchTableId FROM SynchTable WHERE name = 'dbo_DocOrderProducer_Order') AS synchTableId,
            OLD.DocOrderProducerId || '|' || OLD.OrderId,
            (
               CASE OLD.SynchState
                 WHEN 1 THEN
                   IFNULL(OLD.SynchState, '')
                 ELSE NULL
               END
            );
END;
go

-- replication triggers for table dbo_Document
CREATE TRIGGER TI_Synch_dbo_Document
AFTER INSERT ON dbo_Document
FOR EACH ROW
BEGIN
  UPDATE dbo_Document
     SET SynchState = 2
   WHERE DocumentId = NEW.DocumentId;
END;
go

CREATE TRIGGER TU_Synch_dbo_Document
AFTER UPDATE ON dbo_Document
FOR EACH ROW
WHEN (NEW.SynchState = 0 AND OLD.SynchState = 0 AND NOT (NEW.Status = 10 AND NEW.Type IN (3,4,7)))
BEGIN
  UPDATE dbo_Document
     SET SynchState = 1
   WHERE DocumentId = NEW.DocumentId;
END;
go

CREATE TRIGGER TD_Synch_dbo_Document
AFTER DELETE ON dbo_Document
FOR EACH ROW
WHEN (OLD.SynchState <> 2)
BEGIN
  INSERT INTO SynchDeleteLog(SynchTableId, KeyValues, FieldValues)
  SELECT
    (SELECT SynchTableId FROM SynchTable WHERE name = 'dbo_Document') AS synchTableId,
            OLD.DocumentId,
            (
               CASE OLD.SynchState
                 WHEN 1 THEN
                   IFNULL(OLD.Type, '') || '|' ||
                   IFNULL(OLD.SubType, '') || '|' ||
                   IFNULL(OLD.Status, '') || '|' ||
                   IFNULL(OLD.WarehouseId, '') || '|' ||
                   IFNULL(OLD.CustomerId, '') || '|' ||
                   IFNULL(OLD.PayerId, '') || '|' ||
                   IFNULL(OLD.UserId, '') || '|' ||
                   IFNULL(LENGTH(OLD.Number) || ':' || OLD.Number, '') || '|' ||
                   IFNULL(OLD.IssueDate, '') || '|' ||
                   IFNULL(OLD.SellDate, '') || '|' ||
                   IFNULL(LENGTH(OLD.IssuePlace) || ':' || OLD.IssuePlace, '') || '|' ||
                   IFNULL(OLD.CreateDate, '') || '|' ||
                   IFNULL(OLD.CompletionDate, '') || '|' ||
                   IFNULL(OLD.PriceForm, '') || '|' ||
                   IFNULL(OLD.AutoReservation, '') || '|' ||
                   IFNULL(OLD.Priority, '') || '|' ||
                   IFNULL(OLD.PaymentFormId, '') || '|' ||
                   IFNULL(OLD.PaymentTerm, '') || '|' ||
                   IFNULL(OLD.PaymentDate, '') || '|' ||
                   IFNULL(OLD.SourceDocId, '') || '|' ||
                   IFNULL(LENGTH(OLD.SourceDocNumber) || ':' || OLD.SourceDocNumber, '') || '|' ||
                   IFNULL(OLD.SourceDocDate, '') || '|' ||
                   IFNULL(OLD.Discount, '') || '|' ||
                   IFNULL(OLD.DiscountMode, '') || '|' ||
                   IFNULL(OLD.DiscountWorthNet, '') || '|' ||
                   IFNULL(OLD.DiscountWorthGross, '') || '|' ||
                   IFNULL(OLD.WorthNet, '') || '|' ||
                   IFNULL(OLD.WorthGross, '') || '|' ||
                   IFNULL(OLD.WorthPayments, '') || '|' ||
                   IFNULL(OLD.Paid, '') || '|' ||
                   IFNULL(LENGTH(OLD.Remarks) || ':' || OLD.Remarks, '') || '|' ||
                   IFNULL(OLD.ContactId, '') || '|' ||
                   IFNULL(OLD.RemoteDelFlag, '') || '|' ||
                   IFNULL(OLD.PrintCount, '') || '|' ||
                   IFNULL(OLD.DocStatusExtId, '') || '|' ||
                   IFNULL(LENGTH(OLD.DocStatusExtRemarks) || ':' || OLD.DocStatusExtRemarks, '') || '|' ||
                   IFNULL(OLD.NumberValue, '') || '|' ||
				   IFNULL(OLD.TargetWarehouseId, '') || '|' ||
                   IFNULL(OLD.SynchState, '')
                 ELSE NULL
               END
            );
END;
go

-- replication triggers for table dbo_DocumentDetail
CREATE TRIGGER TI_Synch_dbo_DocumentDetail
AFTER INSERT ON dbo_DocumentDetail
FOR EACH ROW
WHEN (NOT EXISTS(SELECT 1 FROM dbo_Document WHERE DocumentId = NEW.TradeDocumentId AND Status = 10 AND Type IN (3,4,7)))
BEGIN
  UPDATE dbo_DocumentDetail
     SET SynchState = 2
   WHERE DocumentDetailId = NEW.DocumentDetailId;
END;
go

CREATE TRIGGER TU_Synch_dbo_DocumentDetail
AFTER UPDATE ON dbo_DocumentDetail
FOR EACH ROW
WHEN (NEW.SynchState = 0 AND OLD.SynchState = 0 AND NOT EXISTS(SELECT 1 FROM dbo_Document WHERE DocumentId = NEW.TradeDocumentId AND Status = 10 AND Type IN (3,4,7)))
BEGIN
  UPDATE dbo_DocumentDetail
     SET SynchState = 1
   WHERE DocumentDetailId = NEW.DocumentDetailId;
END;
go

CREATE TRIGGER TD_Synch_dbo_DocumentDetail
AFTER DELETE ON dbo_DocumentDetail
FOR EACH ROW
WHEN (OLD.SynchState <> 2)
BEGIN
  INSERT INTO SynchDeleteLog(SynchTableId, KeyValues, FieldValues)
  SELECT
    (SELECT SynchTableId FROM SynchTable WHERE name = 'dbo_DocumentDetail') AS synchTableId,
            OLD.DocumentDetailId,
            (
               CASE OLD.SynchState
                 WHEN 1 THEN
                   IFNULL(OLD.TradeDocumentId, '') || '|' ||
                   IFNULL(OLD.WarehouseDocumentId, '') || '|' ||
                   IFNULL(OLD.DocumentPos, '') || '|' ||
                   IFNULL(OLD.ProductUniqueId, '') || '|' ||
                   IFNULL(OLD.WarehouseId, '') || '|' ||
                   IFNULL(OLD.ProductType, '') || '|' ||
                   IFNULL(OLD.StockChange, '') || '|' ||
                   IFNULL(LENGTH(OLD.TaxCode) || ':' || OLD.TaxCode, '') || '|' ||
                   IFNULL(OLD.TaxValue, '') || '|' ||
                   IFNULL(OLD.NetPrice, '') || '|' ||
                   IFNULL(OLD.GrossPrice, '') || '|' ||
                   IFNULL(OLD.Discount, '') || '|' ||
                   IFNULL(OLD.DiscountTotal, '') || '|' ||
                   IFNULL(OLD.NetPriceDiscount, '') || '|' ||
                   IFNULL(OLD.GrossPriceDiscount, '') || '|' ||
                   IFNULL(OLD.Quantity, '') || '|' ||
                   IFNULL(OLD.Reserved, '') || '|' ||
                   IFNULL(OLD.UnitId, '') || '|' ||
                   IFNULL(OLD.ConversionRate, '') || '|' ||
                   IFNULL(OLD.WorthNet, '') || '|' ||
                   IFNULL(OLD.WorthGross, '') || '|' ||
                   IFNULL(LENGTH(OLD.Remarks) || ':' || OLD.Remarks, '') || '|' ||
                   IFNULL(OLD.PriceType, '') || '|' ||
                   IFNULL(OLD.SynchState, '')
                 ELSE NULL
               END
            );
END;
go

-- replication triggers for table dbo_DocumentTax
CREATE TRIGGER TI_Synch_dbo_DocumentTax
AFTER INSERT ON dbo_DocumentTax
FOR EACH ROW
BEGIN
  UPDATE dbo_DocumentTax
     SET SynchState = 2
   WHERE DocumentId = NEW.DocumentId
   AND TaxCode = NEW.TaxCode;
END;
go

CREATE TRIGGER TU_Synch_dbo_DocumentTax
AFTER UPDATE ON dbo_DocumentTax
FOR EACH ROW
WHEN (NEW.SynchState = 0 AND OLD.SynchState = 0)
BEGIN
  UPDATE dbo_DocumentTax
     SET SynchState = 1
   WHERE DocumentId = NEW.DocumentId
   AND TaxCode = NEW.TaxCode;
END;
go

CREATE TRIGGER TD_Synch_dbo_DocumentTax
AFTER DELETE ON dbo_DocumentTax
FOR EACH ROW
WHEN (OLD.SynchState <> 2)
BEGIN
  INSERT INTO SynchDeleteLog(SynchTableId, KeyValues, FieldValues)
  SELECT
    (SELECT SynchTableId FROM SynchTable WHERE name = 'dbo_DocumentTax') AS synchTableId,
            OLD.DocumentId || '|' || IFNULL(LENGTH(OLD.TaxCode) || ':' || OLD.TaxCode, ''),
            (
               CASE OLD.SynchState
                 WHEN 1 THEN
                   IFNULL(OLD.WorthNet, '') || '|' ||
                   IFNULL(OLD.WorthTax, '') || '|' ||
                   IFNULL(OLD.WorthGross, '') || '|' ||
                   IFNULL(OLD.SynchState, '')
                 ELSE NULL
               END
            );
END;
go

-- replication triggers for table dbo_FinancialDocDetail
CREATE TRIGGER TI_Synch_dbo_FinancialDocDetail
AFTER INSERT ON dbo_FinancialDocDetail
FOR EACH ROW
BEGIN
  UPDATE dbo_FinancialDocDetail
     SET SynchState = 2
   WHERE FinDocDetailId = NEW.FinDocDetailId;
END;
go

CREATE TRIGGER TU_Synch_dbo_FinancialDocDetail
AFTER UPDATE ON dbo_FinancialDocDetail
FOR EACH ROW
WHEN (NEW.SynchState = 0 AND OLD.SynchState = 0)
BEGIN
  UPDATE dbo_FinancialDocDetail
     SET SynchState = 1
   WHERE FinDocDetailId = NEW.FinDocDetailId;
END;
go

CREATE TRIGGER TD_Synch_dbo_FinancialDocDetail
AFTER DELETE ON dbo_FinancialDocDetail
FOR EACH ROW
WHEN (OLD.SynchState <> 2)
BEGIN
  INSERT INTO SynchDeleteLog(SynchTableId, KeyValues, FieldValues)
  SELECT
    (SELECT SynchTableId FROM SynchTable WHERE name = 'dbo_FinancialDocDetail') AS synchTableId,
            OLD.FinDocDetailId,
            (
               CASE OLD.SynchState
                 WHEN 1 THEN
                   IFNULL(OLD.FinDocId, '') || '|' ||
                   IFNULL(OLD.BillId, '') || '|' ||
                   IFNULL(OLD.DocumentId, '') || '|' ||
                   IFNULL(OLD.Amount, '') || '|' ||
                   IFNULL(LENGTH(OLD.Title) || ':' || OLD.Title, '') || '|' ||
                   IFNULL(OLD.SynchState, '')
                 ELSE NULL
               END
            );
END;
go

-- replication triggers for table dbo_FinancialDocument
CREATE TRIGGER TI_Synch_dbo_FinancialDocument
AFTER INSERT ON dbo_FinancialDocument
FOR EACH ROW
BEGIN
  UPDATE dbo_FinancialDocument
     SET SynchState = 2
   WHERE FinDocId = NEW.FinDocId;
END;
go

CREATE TRIGGER TU_Synch_dbo_FinancialDocument
AFTER UPDATE ON dbo_FinancialDocument
FOR EACH ROW
WHEN (NEW.SynchState = 0 AND OLD.SynchState = 0)
BEGIN
  UPDATE dbo_FinancialDocument
     SET SynchState = 1
   WHERE FinDocId = NEW.FinDocId;
END;
go

CREATE TRIGGER TD_Synch_dbo_FinancialDocument
AFTER DELETE ON dbo_FinancialDocument
FOR EACH ROW
WHEN (OLD.SynchState <> 2)
BEGIN
  INSERT INTO SynchDeleteLog(SynchTableId, KeyValues, FieldValues)
  SELECT
    (SELECT SynchTableId FROM SynchTable WHERE name = 'dbo_FinancialDocument') AS synchTableId,
            OLD.FinDocId,
            (
               CASE OLD.SynchState
                 WHEN 1 THEN
                   IFNULL(OLD.Type, '') || '|' ||
                   IFNULL(OLD.Status, '') || '|' ||
                   IFNULL(OLD.CustomerId, '') || '|' ||
                   IFNULL(OLD.PayerId, '') || '|' ||
                   IFNULL(OLD.UserId, '') || '|' ||
                   IFNULL(OLD.TillId, '') || '|' ||
                   IFNULL(LENGTH(OLD.Number) || ':' || OLD.Number, '') || '|' ||
                   IFNULL(OLD.IssueDate, '') || '|' ||
                   IFNULL(OLD.CreateDate, '') || '|' ||
                   IFNULL(OLD.Amount, '') || '|' ||
                   IFNULL(LENGTH(OLD.Remarks) || ':' || OLD.Remarks, '') || '|' ||
                   IFNULL(OLD.RemoteDelFlag, '') || '|' ||
                   IFNULL(OLD.PrintCount, '') || '|' ||
                   IFNULL(OLD.NumberValue, '') || '|' ||
                   IFNULL(OLD.SynchState, '')
                 ELSE NULL
               END
            );
END;
go

-- replication triggers for table dbo_ReportRequest
CREATE TRIGGER TI_Synch_dbo_ReportRequest
AFTER INSERT ON dbo_ReportRequest
FOR EACH ROW
BEGIN
  UPDATE dbo_ReportRequest
     SET SynchState = 2
   WHERE UserId = NEW.UserId
   AND ReportId = NEW.ReportId;
END;
go

CREATE TRIGGER TU_Synch_dbo_ReportRequest
AFTER UPDATE ON dbo_ReportRequest
FOR EACH ROW
WHEN (NEW.SynchState = 0 AND OLD.SynchState = 0)
BEGIN
  UPDATE dbo_ReportRequest
     SET SynchState = 1
   WHERE UserId = NEW.UserId
   AND ReportId = NEW.ReportId;
END;
go

CREATE TRIGGER TD_Synch_dbo_ReportRequest
AFTER DELETE ON dbo_ReportRequest
FOR EACH ROW
WHEN (OLD.SynchState <> 2)
BEGIN
  INSERT INTO SynchDeleteLog(SynchTableId, KeyValues, FieldValues)
  SELECT
    (SELECT SynchTableId FROM SynchTable WHERE name = 'dbo_ReportRequest') AS synchTableId,
            OLD.UserId || '|' || OLD.ReportId,
            (
               CASE OLD.SynchState
                 WHEN 1 THEN
                   IFNULL(OLD.DateFrom, '') || '|' ||
                   IFNULL(OLD.DateTo, '') || '|' ||
                   IFNULL(OLD.Status, '') || '|' ||
                   IFNULL(OLD.SynchState, '')
                 ELSE NULL
               END
            );
END;
go

-- replication triggers for table dbo_Route
CREATE TRIGGER TI_Synch_dbo_Route
AFTER INSERT ON dbo_Route
FOR EACH ROW
BEGIN
  UPDATE dbo_Route
     SET SynchState = 2
   WHERE RouteId = NEW.RouteId;
END;
go

CREATE TRIGGER TU_Synch_dbo_Route
AFTER UPDATE ON dbo_Route
FOR EACH ROW
WHEN (NEW.SynchState = 0 AND OLD.SynchState = 0)
BEGIN
  UPDATE dbo_Route
     SET SynchState = 1
   WHERE RouteId = NEW.RouteId;
END;
go

CREATE TRIGGER TD_Synch_dbo_Route
AFTER DELETE ON dbo_Route
FOR EACH ROW
WHEN (OLD.SynchState <> 2)
BEGIN
  INSERT INTO SynchDeleteLog(SynchTableId, KeyValues, FieldValues)
  SELECT
    (SELECT SynchTableId FROM SynchTable WHERE name = 'dbo_Route') AS synchTableId,
            OLD.RouteId,
            (
               CASE OLD.SynchState
                 WHEN 1 THEN
                   IFNULL(OLD.UserId, '') || '|' ||
                   IFNULL(OLD.RouteDate, '') || '|' ||
                   IFNULL(OLD.Approved, '') || '|' ||
                   IFNULL(OLD.SynchState, '')
                 ELSE NULL
               END
            );
END;
go

-- replication triggers for table dbo_RouteDetail
CREATE TRIGGER TI_Synch_dbo_RouteDetail
AFTER INSERT ON dbo_RouteDetail
FOR EACH ROW
BEGIN
  UPDATE dbo_RouteDetail
     SET SynchState = 2
   WHERE RouteId = NEW.RouteId
   AND CustomerId = NEW.CustomerId;
END;
go

CREATE TRIGGER TU_Synch_dbo_RouteDetail
AFTER UPDATE ON dbo_RouteDetail
FOR EACH ROW
WHEN (NEW.SynchState = 0 AND OLD.SynchState = 0)
BEGIN
  UPDATE dbo_RouteDetail
     SET SynchState = 1
   WHERE RouteId = NEW.RouteId
   AND CustomerId = NEW.CustomerId;
END;
go

CREATE TRIGGER TD_Synch_dbo_RouteDetail
AFTER DELETE ON dbo_RouteDetail
FOR EACH ROW
WHEN (OLD.SynchState <> 2)
BEGIN
  INSERT INTO SynchDeleteLog(SynchTableId, KeyValues, FieldValues)
  SELECT
    (SELECT SynchTableId FROM SynchTable WHERE name = 'dbo_RouteDetail') AS synchTableId,
            OLD.RouteId || '|' || OLD.CustomerId,
            (
               CASE OLD.SynchState
                 WHEN 1 THEN
                   IFNULL(OLD.HourPlan, '') || '|' ||
                   IFNULL(OLD.HourBeg, '') || '|' ||
                   IFNULL(OLD.HourEnd, '') || '|' ||
                   IFNULL(OLD.Status, '') || '|' ||
                   IFNULL(OLD.Annexed, '') || '|' ||
                   IFNULL(LENGTH(OLD.Remarks) || ':' || OLD.Remarks, '') || '|' ||
                   IFNULL(OLD.Mileage, '') || '|' ||
                   IFNULL(OLD.RouteKindId, '') || '|' ||
                   IFNULL(OLD.SynchState, '') || '|' ||
                   IFNULL(OLD.ContactId, '') --WERPM-508
                 ELSE NULL
               END
            );
END;
go

-- replication triggers for table dbo_UserPool
CREATE TRIGGER TI_Synch_dbo_UserPool
AFTER INSERT ON dbo_UserPool
FOR EACH ROW
BEGIN
  UPDATE dbo_UserPool
     SET SynchState = 2
   WHERE UserId = NEW.UserId
   AND Type = NEW.Type
   AND FromDate = NEW.FromDate;
END;
go

CREATE TRIGGER TU_Synch_dbo_UserPool
AFTER UPDATE ON dbo_UserPool
FOR EACH ROW
WHEN (NEW.SynchState = 0 AND OLD.SynchState = 0)
BEGIN
  UPDATE dbo_UserPool
     SET SynchState = 1
   WHERE UserId = NEW.UserId
   AND Type = NEW.Type
   AND FromDate = NEW.FromDate;
END;
go

CREATE TRIGGER TD_Synch_dbo_UserPool
AFTER DELETE ON dbo_UserPool
FOR EACH ROW
WHEN (OLD.SynchState <> 2)
BEGIN
  INSERT INTO SynchDeleteLog(SynchTableId, KeyValues, FieldValues)
  SELECT
    (SELECT SynchTableId FROM SynchTable WHERE name = 'dbo_UserPool') AS synchTableId,
            OLD.UserId || '|' || OLD.Type || '|' || OLD.FromDate,
            (
               CASE OLD.SynchState
                 WHEN 1 THEN
                   IFNULL(OLD.NextValue, '') || '|' ||
                   IFNULL(OLD.SynchState, '')
                 ELSE NULL
               END
            );
END;
go

-- replication triggers for table dbo_SurveyResult
CREATE TRIGGER TI_Synch_dbo_SurveyResult
AFTER INSERT ON dbo_SurveyResult
FOR EACH ROW
BEGIN
  UPDATE dbo_SurveyResult
     SET SynchState = 2
   WHERE SurveyResultId = NEW.SurveyResultId;
END;
go

CREATE TRIGGER TU_Synch_dbo_SurveyResult
AFTER UPDATE ON dbo_SurveyResult
FOR EACH ROW
WHEN (NEW.SynchState = 0 AND OLD.SynchState = 0)
BEGIN
  UPDATE dbo_SurveyResult
     SET SynchState = 1
   WHERE SurveyResultId = NEW.SurveyResultId;
END;
go

CREATE TRIGGER TD_Synch_dbo_SurveyResult
AFTER DELETE ON dbo_SurveyResult
FOR EACH ROW
WHEN (OLD.SynchState <> 2)
BEGIN
  INSERT INTO SynchDeleteLog(SynchTableId, KeyValues, FieldValues)
  SELECT
    (SELECT SynchTableId FROM SynchTable WHERE name = 'dbo_SurveyResult') AS synchTableId,
            OLD.SurveyResultId,
            (
               CASE OLD.SynchState
                 WHEN 1 THEN
                   IFNULL(OLD.SurveyResultId, '') || '|' ||
                   IFNULL(OLD.SurveyId, '') || '|' ||
				   IFNULL(OLD.RouteId, '') || '|' ||
				   IFNULL(OLD.AppCardId, '') || '|' ||
				   IFNULL(OLD.SourceId, '') || '|' ||
				   IFNULL(OLD.SurveyDate, '') || '|' ||
				   IFNULL(OLD.UserId, '') || '|' ||
				   IFNULL(OLD.ReadyToSendStatus, '') || '|' ||				   
                   IFNULL(OLD.SynchState, '')
                 ELSE NULL
               END
            );
END;
go

-- replication triggers for table dbo_SurveyResultDetail
CREATE TRIGGER TI_Synch_dbo_SurveyResultDetail
AFTER INSERT ON dbo_SurveyResultDetail
FOR EACH ROW
BEGIN
  UPDATE dbo_SurveyResultDetail
     SET SynchState = 2
   WHERE SurveyResultId = NEW.SurveyResultId
   AND SurveyAnswerId = NEW.SurveyAnswerId;
END;
go

CREATE TRIGGER TU_Synch_dbo_SurveyResultDetail
AFTER UPDATE ON dbo_SurveyResultDetail
FOR EACH ROW
WHEN (NEW.SynchState = 0 AND OLD.SynchState = 0)
BEGIN
  UPDATE dbo_SurveyResultDetail
     SET SynchState = 1
   WHERE SurveyResultId = NEW.SurveyResultId
   AND SurveyAnswerId = NEW.SurveyAnswerId;
END;
go

CREATE TRIGGER TD_Synch_dbo_SurveyResultDetail
AFTER DELETE ON dbo_SurveyResultDetail
FOR EACH ROW
WHEN (OLD.SynchState <> 2)
BEGIN
  INSERT INTO SynchDeleteLog(SynchTableId, KeyValues, FieldValues)
  SELECT
    (SELECT SynchTableId FROM SynchTable WHERE name = 'dbo_SurveyResultDetail') AS synchTableId,
            OLD.SurveyResultId,
            (
               CASE OLD.SynchState
                 WHEN 1 THEN
                   IFNULL(OLD.SurveyResultId, '') || '|' ||
                   IFNULL(OLD.SurveyAnswerId, '') || '|' ||	
				   IFNULL(LENGTH(OLD.Value) || ':' || OLD.Value, '') || '|' ||	   			   
                   IFNULL(OLD.SynchState, '')
                 ELSE NULL
               END
            );
END;
go

--zakladamy, ze bedziemy przechowywac tylko informacje o ostatniej poprawnej replikacji,
--w replikacji tylko update
INSERT INTO SynchInfo(LastSynchDateBegin, LastSynchDateEnd, LastUploadBytes, LastDownloadBytes, SynchResult, IsAuto)
    VALUES ('1970-01-01 00:00:00.000', '1970-01-01 00:00:00.000', 0, 0, 0, 0);
go

INSERT INTO SynchTable ( Name, IsUploadEnable, IsDownloadEnable, TableId ) VALUES ( 'dbo_User', 0, 1, 1 );
go
INSERT INTO SynchTable ( Name, IsUploadEnable, IsDownloadEnable, TableId ) VALUES ( 'dbo_Company', 1, 1, 2 );
go
INSERT INTO SynchTable ( Name, IsUploadEnable, IsDownloadEnable, TableId ) VALUES ( 'dbo_UserPool', 1, 1, 3 );
go
INSERT INTO SynchTable ( Name, IsUploadEnable, IsDownloadEnable, TableId ) VALUES ( 'dbo_DocNumeration', 1, 1, 4 );
go
INSERT INTO SynchTable ( Name, IsUploadEnable, IsDownloadEnable, TableId ) VALUES ( 'dbo_AccessDefinition', 0, 1, 5 );
go
INSERT INTO SynchTable ( Name, IsUploadEnable, IsDownloadEnable, TableId ) VALUES ( 'dbo_ResourceAssignment', 0, 1, 6 );
go
INSERT INTO SynchTable ( Name, IsUploadEnable, IsDownloadEnable, TableId ) VALUES ( 'dbo_Product', 1, 1, 7 );
go
INSERT INTO SynchTable ( Name, IsUploadEnable, IsDownloadEnable, TableId ) VALUES ( 'dbo_ProductWarehouse', 1, 1, 8 );
go
INSERT INTO SynchTable ( Name, IsUploadEnable, IsDownloadEnable, TableId ) VALUES ( 'dbo_Unit', 1, 1, 9 );
go
INSERT INTO SynchTable ( Name, IsUploadEnable, IsDownloadEnable, TableId ) VALUES ( 'dbo_ProductUnit', 1, 1, 10 );
go
INSERT INTO SynchTable ( Name, IsUploadEnable, IsDownloadEnable, TableId ) VALUES ( 'dbo_ProductCategory', 1, 1, 11 );
go
INSERT INTO SynchTable ( Name, IsUploadEnable, IsDownloadEnable, TableId ) VALUES ( 'dbo_IndividualPrice', 1, 1, 12 );
go
INSERT INTO SynchTable ( Name, IsUploadEnable, IsDownloadEnable, TableId ) VALUES ( 'dbo_ProductPrice', 1, 1, 13 );
go
INSERT INTO SynchTable ( Name, IsUploadEnable, IsDownloadEnable, TableId ) VALUES ( 'dbo_Customer', 1, 1, 14 );
go
INSERT INTO SynchTable ( Name, IsUploadEnable, IsDownloadEnable, TableId ) VALUES ( 'dbo_CustomerGroupPrice', 0, 1, 15 );
go
INSERT INTO SynchTable ( Name, IsUploadEnable, IsDownloadEnable, TableId ) VALUES ( 'dbo_CustomerGroup', 0, 1, 16 );
go
INSERT INTO SynchTable ( Name, IsUploadEnable, IsDownloadEnable, TableId ) VALUES ( 'dbo_CustomerClassification', 0, 1, 17 );
go
INSERT INTO SynchTable ( Name, IsUploadEnable, IsDownloadEnable, TableId ) VALUES ( 'dbo_CustomerContact', 1, 1, 18 );
go
INSERT INTO SynchTable ( Name, IsUploadEnable, IsDownloadEnable, TableId ) VALUES ( 'dbo_CustomerBankAccount', 1, 1, 19 );
go
INSERT INTO SynchTable ( Name, IsUploadEnable, IsDownloadEnable, TableId ) VALUES ( 'dbo_Document', 1, 1, 20 );
go
INSERT INTO SynchTable ( Name, IsUploadEnable, IsDownloadEnable, TableId ) VALUES ( 'dbo_DocumentDetail', 1, 1, 21 );
go
INSERT INTO SynchTable ( Name, IsUploadEnable, IsDownloadEnable, TableId ) VALUES ( 'dbo_DocOrderProducer', 1, 1, 22 );
go
INSERT INTO SynchTable ( Name, IsUploadEnable, IsDownloadEnable, TableId ) VALUES ( 'dbo_DocOrderProducerDetail', 0, 1, 23 );
go
INSERT INTO SynchTable ( Name, IsUploadEnable, IsDownloadEnable, TableId ) VALUES ( 'dbo_DocOrderProducer_Order', 1, 1, 24 );
go
INSERT INTO SynchTable ( Name, IsUploadEnable, IsDownloadEnable, TableId ) VALUES ( 'dbo_DocumentTax', 1, 1, 25 );
go
INSERT INTO SynchTable ( Name, IsUploadEnable, IsDownloadEnable, TableId ) VALUES ( 'dbo_DocumentError', 0, 1, 26 );
go
INSERT INTO SynchTable ( Name, IsUploadEnable, IsDownloadEnable, TableId ) VALUES ( 'dbo_DocStatusExt', 0, 1, 27 );
go
INSERT INTO SynchTable ( Name, IsUploadEnable, IsDownloadEnable, TableId ) VALUES ( 'dbo_Bill', 1, 1, 28 );
go
INSERT INTO SynchTable ( Name, IsUploadEnable, IsDownloadEnable, TableId ) VALUES ( 'dbo_FinancialDocument', 1, 1, 29 );
go
INSERT INTO SynchTable ( Name, IsUploadEnable, IsDownloadEnable, TableId ) VALUES ( 'dbo_FinancialDocDetail', 1, 1, 30 );
go
INSERT INTO SynchTable ( Name, IsUploadEnable, IsDownloadEnable, TableId ) VALUES ( 'dbo_Route', 1, 1, 31 );
go
INSERT INTO SynchTable ( Name, IsUploadEnable, IsDownloadEnable, TableId ) VALUES ( 'dbo_RouteDetail', 1, 1, 32 );
go
INSERT INTO SynchTable ( Name, IsUploadEnable, IsDownloadEnable, TableId ) VALUES ( 'dbo_PaymentForm', 0, 1, 33 );
go
INSERT INTO SynchTable ( Name, IsUploadEnable, IsDownloadEnable, TableId ) VALUES ( 'dbo_Region', 0, 1, 34 );
go
INSERT INTO SynchTable ( Name, IsUploadEnable, IsDownloadEnable, TableId ) VALUES ( 'dbo_Warehouse', 0, 1, 35 );
go
INSERT INTO SynchTable ( Name, IsUploadEnable, IsDownloadEnable, TableId ) VALUES ( 'dbo_Price', 1, 1, 36 );
go
INSERT INTO SynchTable ( Name, IsUploadEnable, IsDownloadEnable, TableId ) VALUES ( 'dbo_Till', 0, 1, 37 );
go
INSERT INTO SynchTable ( Name, IsUploadEnable, IsDownloadEnable, TableId ) VALUES ( 'dbo_RouteKind', 0, 1, 38 );
go
INSERT INTO SynchTable ( Name, IsUploadEnable, IsDownloadEnable, TableId ) VALUES ( 'dbo_PubTime', 0, 1, 39 );
go
INSERT INTO SynchTable ( Name, IsUploadEnable, IsDownloadEnable, TableId ) VALUES ( 'dbo_Parameter', 0, 1, 40 );
go
INSERT INTO SynchTable ( Name, IsUploadEnable, IsDownloadEnable, TableId ) VALUES ( 'dbo_DocNumerationDef', 0, 1, 41 );
go
INSERT INTO SynchTable ( Name, IsUploadEnable, IsDownloadEnable, TableId ) VALUES ( 'dbo_DayReport', 1, 1, 42 );
go
INSERT INTO SynchTable ( Name, IsUploadEnable, IsDownloadEnable, TableId ) VALUES ( 'dbo_Message', 1, 1, 43 );
go
INSERT INTO SynchTable ( Name, IsUploadEnable, IsDownloadEnable, TableId ) VALUES ( 'dbo_Report', 0, 1, 44 );
go
INSERT INTO SynchTable ( Name, IsUploadEnable, IsDownloadEnable, TableId ) VALUES ( 'dbo_ReportRequest', 1, 1, 45 );
go
INSERT INTO SynchTable ( Name, IsUploadEnable, IsDownloadEnable, TableId ) VALUES ( 'dbo_ReportValues', 0, 1, 46 );
go
INSERT INTO SynchTable ( Name, IsUploadEnable, IsDownloadEnable, TableId ) VALUES ( 'dbo_TranslateDictionary', 0, 1, 47 );
go
INSERT INTO SynchTable ( Name, IsUploadEnable, IsDownloadEnable, TableId ) VALUES ( 'dbo_MobileTranslation', 0, 1, 48 );
go
INSERT INTO SynchTable ( Name, IsUploadEnable, IsDownloadEnable, TableId ) VALUES ( 'dbo_Attribute', 0, 1, 49 );
go
INSERT INTO SynchTable ( Name, IsUploadEnable, IsDownloadEnable, TableId ) VALUES ( 'dbo_AttributeDetail', 0, 1, 50 );
go
INSERT INTO SynchTable ( Name, IsUploadEnable, IsDownloadEnable, TableId ) VALUES ( 'dbo_AttributeValue', 1, 1, 51 );
go
INSERT INTO SynchTable ( Name, IsUploadEnable, IsDownloadEnable, TableId ) VALUES ( 'dbo_Survey', 0, 1, 52 );
go
INSERT INTO SynchTable ( Name, IsUploadEnable, IsDownloadEnable, TableId ) VALUES ( 'dbo_SurveyAssignment', 0, 1, 53 );
go
INSERT INTO SynchTable ( Name, IsUploadEnable, IsDownloadEnable, TableId ) VALUES ( 'dbo_SurveyQuestion', 0, 1, 54 );
go
INSERT INTO SynchTable ( Name, IsUploadEnable, IsDownloadEnable, TableId ) VALUES ( 'dbo_SurveyAnswer', 0, 1, 55 );
go
INSERT INTO SynchTable ( Name, IsUploadEnable, IsDownloadEnable, TableId ) VALUES ( 'dbo_SurveyResult', 1, 1, 56 );
go
INSERT INTO SynchTable ( Name, IsUploadEnable, IsDownloadEnable, TableId ) VALUES ( 'dbo_SurveyResultDetail', 1, 1, 57 );
go
INSERT INTO SynchTable ( Name, IsUploadEnable, IsDownloadEnable, TableId ) VALUES ( 'dbo_ProductCategoryTree', 0, 1, 58 );
go
INSERT INTO SynchTable ( Name, IsUploadEnable, IsDownloadEnable, TableId, ClearAfterUpload ) VALUES ( 'dbo_GeolocationLog', 1, 0, 59, 1 );
go
INSERT INTO SynchTable ( Name, IsUploadEnable, IsDownloadEnable, TableId ) VALUES ( 'dbo_DocRemarks', 0, 1, 60 );
go
INSERT INTO SynchTable ( Name, IsUploadEnable, IsDownloadEnable, TableId, ClearAfterUpload ) VALUES ( 'dbo_PriceHistory', 1, 0, 61, 1 );
go
INSERT INTO SynchTable ( Name, IsUploadEnable, IsDownloadEnable, TableId, ContainMultimedia, MultimediaColumn, MultimediaExtensionColumn) VALUES ( 'dbo_AttributeValueBinary', 1, 1, 62, 1, "Value", "FileType");
go
INSERT INTO SynchTable ( Name, IsUploadEnable, IsDownloadEnable, TableId ) VALUES ( 'dbo_AttributeValueBinaryCollection', 0, 1, 63 );
go
INSERT INTO SynchTable ( Name, IsUploadEnable, IsDownloadEnable, TableId ) VALUES ( 'dbo_Currency', 0, 1, 64 );
go
INSERT INTO SynchTable ( Name, IsUploadEnable, IsDownloadEnable, TableId ) VALUES ( 'dbo_TargetMeasure', 0, 1, 65 );
go
INSERT INTO SynchTable ( Name, IsUploadEnable, IsDownloadEnable, TableId ) VALUES ( 'dbo_TargetAlgorithm', 0, 1, 66 );
go
INSERT INTO SynchTable ( Name, IsUploadEnable, IsDownloadEnable, TableId ) VALUES ( 'dbo_TargetProfileItemType', 0, 1, 67 );
go
INSERT INTO SynchTable ( Name, IsUploadEnable, IsDownloadEnable, TableId ) VALUES ( 'dbo_TargetProfile', 0, 1, 68 );
go
INSERT INTO SynchTable ( Name, IsUploadEnable, IsDownloadEnable, TableId ) VALUES ( 'dbo_TargetProfileItem', 0, 1, 69 );
go
INSERT INTO SynchTable ( Name, IsUploadEnable, IsDownloadEnable, TableId ) VALUES ( 'dbo_TargetTemplate', 0, 1, 70 );
go
INSERT INTO SynchTable ( Name, IsUploadEnable, IsDownloadEnable, TableId ) VALUES ( 'dbo_Target', 0, 1, 71 );
go
INSERT INTO SynchTable ( Name, IsUploadEnable, IsDownloadEnable, TableId ) VALUES ( 'dbo_Barcode', 0, 1, 72 );
go
INSERT INTO SynchTable ( Name, IsUploadEnable, IsDownloadEnable, TableId ) VALUES ( 'dbo_UserCustomer', 0, 1, 73 );
go